@@ -3,6 +3,7 @@ import os.path as osp
 import re
 import sys
 import warnings
+from abc import ABC, abstractmethod
 from collections.abc import Sequence
 from typing import Any, Callable, List, Optional, Tuple, Union
 
@@ -10,20 +11,20 @@ import numpy as np
 import torch.utils.data
 from torch import Tensor
 
-from torch_geometric.data import Data
+from torch_geometric.data.data import BaseData
 from torch_geometric.data.makedirs import makedirs
 
 IndexType = Union[slice, Tensor, np.ndarray, Sequence]
 
 
-class Dataset(torch.utils.data.Dataset):
+class Dataset(torch.utils.data.Dataset, ABC):
     r"""Dataset base class for creating graph datasets.
-    See `here <https://pytorch-geometric.readthedocs.io/en/latest/notes/
+    See `here <https://pytorch-geometric.readthedocs.io/en/latest/tutorial/
     create_dataset.html>`__ for the accompanying tutorial.
 
     Args:
-        root (string, optional): Root directory where the dataset should be
-            saved. (optional: :obj:`None`)
+        root (str, optional): Root directory where the dataset should be saved.
+            (optional: :obj:`None`)
         transform (callable, optional): A function/transform that takes in an
             :obj:`torch_geometric.data.Data` object and returns a transformed
             version. The data object will be transformed before every access.
@@ -59,11 +60,13 @@ class Dataset(torch.utils.data.Dataset):
         r"""Processes the dataset to the :obj:`self.processed_dir` folder."""
         raise NotImplementedError
 
+    @abstractmethod
     def len(self) -> int:
         r"""Returns the number of graphs stored in the dataset."""
         raise NotImplementedError
 
-    def get(self, idx: int) -> Data:
+    @abstractmethod
+    def get(self, idx: int) -> BaseData:
         r"""Gets the data object at index :obj:`idx`."""
         raise NotImplementedError
 
@@ -87,10 +90,10 @@ class Dataset(torch.utils.data.Dataset):
         self.log = log
         self._indices: Optional[Sequence] = None
 
-        if self.download.__qualname__.split('.')[0] != 'Dataset':
+        if self.has_download:
             self._download()
 
-        if self.process.__qualname__.split('.')[0] != 'Dataset':
+        if self.has_process:
             self._process()
 
     def indices(self) -> Sequence:
@@ -149,7 +152,13 @@ class Dataset(torch.utils.data.Dataset):
     @property
     def num_classes(self) -> int:
         r"""Returns the number of classes in the dataset."""
-        y = torch.cat([data.y for data in self], dim=0)
+        # We iterate over the dataset and collect all labels to determine the
+        # maximum number of classes. Importantly, in rare cases, `__getitem__`
+        # may produce a tuple of data objects (e.g., when used in combination
+        # with `RandomLinkSplit`, so we take care of this case here as well:
+        data_list = _get_flattened_data_list([data for data in self])
+        y = torch.cat([data.y for data in data_list if 'y' in data], dim=0)
+
         # Do not fill cache for `InMemoryDataset`:
         if hasattr(self, '_data_list') and self._data_list is not None:
             self._data_list = self.len() * [None]
@@ -177,6 +186,11 @@ class Dataset(torch.utils.data.Dataset):
             files = files()
         return [osp.join(self.processed_dir, f) for f in to_list(files)]
 
+    @property
+    def has_download(self) -> bool:
+        r"""Checks whether the dataset defines a :meth:`download` method."""
+        return overrides_method(self.__class__, 'download')
+
     def _download(self):
         if files_exist(self.raw_paths):  # pragma: no cover
             return
@@ -184,6 +198,11 @@ class Dataset(torch.utils.data.Dataset):
         makedirs(self.raw_dir)
         self.download()
 
+    @property
+    def has_process(self) -> bool:
+        r"""Checks whether the dataset defines a :meth:`process` method."""
+        return overrides_method(self.__class__, 'process')
+
     def _process(self):
         f = osp.join(self.processed_dir, 'pre_transform.pt')
         if osp.exists(f) and torch.load(f) != _repr(self.pre_transform):
@@ -204,7 +223,7 @@ class Dataset(torch.utils.data.Dataset):
         if files_exist(self.processed_paths):  # pragma: no cover
             return
 
-        if self.log:
+        if self.log and 'pytest' not in sys.modules:
             print('Processing...', file=sys.stderr)
 
         makedirs(self.processed_dir)
@@ -215,7 +234,7 @@ class Dataset(torch.utils.data.Dataset):
         path = osp.join(self.processed_dir, 'pre_filter.pt')
         torch.save(_repr(self.pre_filter), path)
 
-        if self.log:
+        if self.log and 'pytest' not in sys.modules:
             print('Done!', file=sys.stderr)
 
     def __len__(self) -> int:
@@ -225,7 +244,7 @@ class Dataset(torch.utils.data.Dataset):
     def __getitem__(
         self,
         idx: Union[int, np.integer, IndexType],
-    ) -> Union['Dataset', Data]:
+    ) -> Union['Dataset', BaseData]:
         r"""In case :obj:`idx` is of type integer, will return the data object
         at index :obj:`idx` (and transforms it in case :obj:`transform` is
         present).
@@ -263,7 +282,7 @@ class Dataset(torch.utils.data.Dataset):
         elif isinstance(idx, np.ndarray) and idx.dtype == np.int64:
             return self.index_select(idx.flatten().tolist())
 
-        elif isinstance(idx, np.ndarray) and idx.dtype == np.bool:
+        elif isinstance(idx, np.ndarray) and idx.dtype == bool:
             idx = idx.flatten().nonzero()[0]
             return self.index_select(idx.flatten().tolist())
 
@@ -304,9 +323,46 @@ class Dataset(torch.utils.data.Dataset):
         from torch_geometric.data.summary import Summary
         return Summary.from_dataset(self)
 
-    def print_summary(self):
+    def print_summary(self):  # pragma: no cover
         r"""Prints summary statistics of the dataset to the console."""
-        return str(self.get_summary())
+        print(str(self.get_summary()))
+
+    def to_datapipe(self):
+        r"""Converts the dataset into a :class:`torch.utils.data.DataPipe`.
+
+        The returned instance can then be used with :pyg:`PyG's` built-in
+        :class:`DataPipes` for baching graphs as follows:
+
+        .. code-block:: python
+
+            from torch_geometric.datasets import QM9
+
+            dp = QM9(root='./data/QM9/').to_datapipe()
+            dp = dp.batch_graphs(batch_size=2, drop_last=True)
+
+            for batch in dp:
+                pass
+
+        See the `PyTorch tutorial
+        <https://pytorch.org/data/main/tutorial.html>`_ for further background
+        on DataPipes.
+        """
+        from torch_geometric.data.datapipes import DatasetAdapter
+
+        return DatasetAdapter(self)
+
+
+def overrides_method(cls, method_name: str):
+    from torch_geometric.data import InMemoryDataset
+
+    if method_name in cls.__dict__:
+        return True
+
+    out = False
+    for base in cls.__bases__:
+        if base != Dataset and base != InMemoryDataset:
+            out |= overrides_method(base, method_name)
+    return out
 
 
 def to_list(value: Any) -> Sequence:
@@ -325,4 +381,16 @@ def files_exist(files: List[str]) -> bool:
 def _repr(obj: Any) -> str:
     if obj is None:
         return 'None'
-    return re.sub('(<.*?)\\s.*(>)', r'\1\2', obj.__repr__())
+    return re.sub('(<.*?)\\s.*(>)', r'\1\2', str(obj))
+
+
+def _get_flattened_data_list(data_list: List[Any]) -> List[BaseData]:
+    outs: List[BaseData] = []
+    for data in data_list:
+        if isinstance(data, BaseData):
+            outs.append(data)
+        elif isinstance(data, (tuple, list)):
+            outs.extend(_get_flattened_data_list(data))
+        elif isinstance(data, dict):
+            outs.extend(_get_flattened_data_list(data.values()))
+    return outs
