@@ -4,7 +4,7 @@ import sys
 import urllib
 from typing import Optional
 
-from .makedirs import makedirs
+from torch_geometric.data.makedirs import makedirs
 
 
 def download_url(url: str, folder: str, log: bool = True,
@@ -12,8 +12,8 @@ def download_url(url: str, folder: str, log: bool = True,
     r"""Downloads the content of an URL to a specific folder.
 
     Args:
-        url (string): The url.
-        folder (string): The folder.
+        url (str): The URL.
+        folder (str): The folder.
         log (bool, optional): If :obj:`False`, will not print anything to the
             console. (default: :obj:`True`)
     """
@@ -25,11 +25,11 @@ def download_url(url: str, folder: str, log: bool = True,
     path = osp.join(folder, filename)
 
     if osp.exists(path):  # pragma: no cover
-        if log:
+        if log and 'pytest' not in sys.modules:
             print(f'Using existing file {filename}', file=sys.stderr)
         return path
 
-    if log:
+    if log and 'pytest' not in sys.modules:
         print(f'Downloading {url}', file=sys.stderr)
 
     makedirs(folder)
