@@ -7,7 +7,7 @@ import zipfile
 
 
 def maybe_log(path, log=True):
-    if log:
+    if log and 'pytest' not in sys.modules:
         print(f'Extracting {path}', file=sys.stderr)
 
 
@@ -15,9 +15,9 @@ def extract_tar(path: str, folder: str, mode: str = 'r:gz', log: bool = True):
     r"""Extracts a tar archive to a specific folder.
 
     Args:
-        path (string): The path to the tar archive.
-        folder (string): The folder.
-        mode (string, optional): The compression mode. (default: :obj:`"r:gz"`)
+        path (str): The path to the tar archive.
+        folder (str): The folder.
+        mode (str, optional): The compression mode. (default: :obj:`"r:gz"`)
         log (bool, optional): If :obj:`False`, will not print anything to the
             console. (default: :obj:`True`)
     """
@@ -30,8 +30,8 @@ def extract_zip(path: str, folder: str, log: bool = True):
     r"""Extracts a zip archive to a specific folder.
 
     Args:
-        path (string): The path to the tar archive.
-        folder (string): The folder.
+        path (str): The path to the tar archive.
+        folder (str): The folder.
         log (bool, optional): If :obj:`False`, will not print anything to the
             console. (default: :obj:`True`)
     """
@@ -44,8 +44,8 @@ def extract_bz2(path: str, folder: str, log: bool = True):
     r"""Extracts a bz2 archive to a specific folder.
 
     Args:
-        path (string): The path to the tar archive.
-        folder (string): The folder.
+        path (str): The path to the tar archive.
+        folder (str): The folder.
         log (bool, optional): If :obj:`False`, will not print anything to the
             console. (default: :obj:`True`)
     """
@@ -60,8 +60,8 @@ def extract_gz(path: str, folder: str, log: bool = True):
     r"""Extracts a gz archive to a specific folder.
 
     Args:
-        path (string): The path to the tar archive.
-        folder (string): The folder.
+        path (str): The path to the tar archive.
+        folder (str): The folder.
         log (bool, optional): If :obj:`False`, will not print anything to the
             console. (default: :obj:`True`)
     """
