@@ -1,26 +1,28 @@
 import copy
+import warnings
+from abc import ABC
 from collections.abc import Mapping, Sequence
-from typing import Callable, Dict, Iterable, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, Iterable, List, Optional, Tuple, Union
 
 from torch import Tensor
 
-from torch_geometric.data import Data
+from torch_geometric.data import Batch, Data
 from torch_geometric.data.collate import collate
 from torch_geometric.data.dataset import Dataset, IndexType
 from torch_geometric.data.separate import separate
 
 
-class InMemoryDataset(Dataset):
+class InMemoryDataset(Dataset, ABC):
     r"""Dataset base class for creating graph datasets which easily fit
     into CPU memory.
     Inherits from :class:`torch_geometric.data.Dataset`.
-    See `here <https://pytorch-geometric.readthedocs.io/en/latest/notes/
+    See `here <https://pytorch-geometric.readthedocs.io/en/latest/tutorial/
     create_dataset.html#creating-in-memory-datasets>`__ for the accompanying
     tutorial.
 
     Args:
-        root (string, optional): Root directory where the dataset should be
-            saved. (default: :obj:`None`)
+        root (str, optional): Root directory where the dataset should be saved.
+            (optional: :obj:`None`)
         transform (callable, optional): A function/transform that takes in an
             :obj:`torch_geometric.data.Data` object and returns a transformed
             version. The data object will be transformed before every access.
@@ -53,14 +55,14 @@ class InMemoryDataset(Dataset):
         log: bool = True,
     ):
         super().__init__(root, transform, pre_transform, pre_filter, log)
-        self.data = None
+        self._data = None
         self.slices = None
         self._data_list: Optional[List[Data]] = None
 
     @property
     def num_classes(self) -> int:
         if self.transform is None:
-            return self._infer_num_classes(self.data.y)
+            return self._infer_num_classes(self._data.y)
         return super().num_classes
 
     def len(self) -> int:
@@ -72,7 +74,7 @@ class InMemoryDataset(Dataset):
 
     def get(self, idx: int) -> Data:
         if self.len() == 1:
-            return copy.copy(self.data)
+            return copy.copy(self._data)
 
         if not hasattr(self, '_data_list') or self._data_list is None:
             self._data_list = self.len() * [None]
@@ -80,8 +82,8 @@ class InMemoryDataset(Dataset):
             return copy.copy(self._data_list[idx])
 
         data = separate(
-            cls=self.data.__class__,
-            batch=self.data,
+            cls=self._data.__class__,
+            batch=self._data,
             idx=idx,
             slice_dict=self.slices,
             decrement=False,
@@ -127,6 +129,52 @@ class InMemoryDataset(Dataset):
         dataset.data, dataset.slices = self.collate(data_list)
         return dataset
 
+    @property
+    def data(self) -> Any:
+        msg1 = ("It is not recommended to directly access the internal "
+                "storage format `data` of an 'InMemoryDataset'.")
+        msg2 = ("The given 'InMemoryDataset' only references a subset of "
+                "examples of the full dataset, but 'data' will contain "
+                "information of the full dataset.")
+        msg3 = ("The data of the dataset is already cached, so any "
+                "modifications to `data` will not be reflected when accessing "
+                "its elements. Clearing the cache now by removing all "
+                "elements in `dataset._data_list`.")
+        msg4 = ("If you are absolutely certain what you are doing, access the "
+                "internal storage via `InMemoryDataset._data` instead to "
+                "suppress this warning. Alternatively, you can access stacked "
+                "individual attributes of every graph via "
+                "`dataset.{attr_name}`.")
+
+        msg = msg1
+        if self._indices is not None:
+            msg += f' {msg2}'
+        if self._data_list is not None:
+            msg += f' {msg3}'
+            self._data_list = None
+        msg += f' {msg4}'
+
+        warnings.warn(msg)
+
+        return self._data
+
+    @data.setter
+    def data(self, value: Any):
+        self._data = value
+        self._data_list = None
+
+    def __getattr__(self, key: str) -> Any:
+        data = self.__dict__.get('_data')
+        if isinstance(data, Data) and key in data:
+            if self._indices is None and data.__inc__(key, data[key]) == 0:
+                return data[key]
+            else:
+                data_list = [self.get(i) for i in self.indices()]
+                return Batch.from_data_list(data_list)[key]
+
+        raise AttributeError(f"'{self.__class__.__name__}' object has no "
+                             f"attribute '{key}'")
+
 
 def nested_iter(node: Union[Mapping, Sequence]) -> Iterable:
     if isinstance(node, Mapping):
