@@ -43,12 +43,13 @@ from .pascal import PascalVOCKeypoints
 from .pascal_pf import PascalPF
 from .snap_dataset import SNAPDataset
 from .suite_sparse import SuiteSparseMatrixCollection
-# from .particle import TrackMLParticleTrackingDataset
 from .aminer import AMiner
 from .word_net import WordNet18, WordNet18RR
+from .freebase import FB15k_237
 from .wikics import WikiCS
 from .webkb import WebKB
 from .wikipedia_network import WikipediaNetwork
+from .heterophilous_graph_dataset import HeterophilousGraphDataset
 from .actor import Actor
 from .ogb_mag import OGB_MAG
 from .dblp import DBLP
@@ -78,6 +79,12 @@ from .linkx_dataset import LINKXDataset
 from .elliptic import EllipticBitcoinDataset
 from .dgraph import DGraphFin
 from .hydro_net import HydroNet
+from .explainer_dataset import ExplainerDataset
+from .infection_dataset import InfectionDataset
+from .ba2motif_dataset import BA2MotifDataset
+from .ba_multi_shapes import BAMultiShapesDataset
+from .airfrans import AirfRANS
+from .taobao import Taobao
 
 import torch_geometric.datasets.utils  # noqa
 
@@ -129,13 +136,14 @@ __all__ = [
     'PascalPF',
     'SNAPDataset',
     'SuiteSparseMatrixCollection',
-    # 'TrackMLParticleTrackingDataset',
     'AMiner',
     'WordNet18',
     'WordNet18RR',
+    'FB15k_237',
     'WikiCS',
     'WebKB',
     'WikipediaNetwork',
+    'HeterophilousGraphDataset',
     'Actor',
     'OGB_MAG',
     'DBLP',
@@ -165,6 +173,12 @@ __all__ = [
     'EllipticBitcoinDataset',
     'DGraphFin',
     'HydroNet',
+    'ExplainerDataset',
+    'InfectionDataset',
+    'BA2MotifDataset',
+    'BAMultiShapesDataset',
+    'AirfRANS',
+    'Taobao',
 ]
 
 classes = __all__
