@@ -19,7 +19,7 @@ class MNISTSuperpixels(InMemoryDataset):
     Every graph is labeled by one of 10 classes.
 
     Args:
-        root (string): Root directory where the dataset should be saved.
+        root (str): Root directory where the dataset should be saved.
         train (bool, optional): If :obj:`True`, loads the training dataset,
             otherwise the test dataset. (default: :obj:`True`)
         transform (callable, optional): A function/transform that takes in an
@@ -35,21 +35,22 @@ class MNISTSuperpixels(InMemoryDataset):
             value, indicating whether the data object should be included in the
             final dataset. (default: :obj:`None`)
 
-    Stats:
-        .. list-table::
-            :widths: 10 10 10 10 10
-            :header-rows: 1
+    **STATS:**
 
-            * - #graphs
-              - #nodes
-              - #edges
-              - #features
-              - #classes
-            * - 70,000
-              - 75
-              - ~1,393.0
-              - 1
-              - 10
+    .. list-table::
+        :widths: 10 10 10 10 10
+        :header-rows: 1
+
+        * - #graphs
+          - #nodes
+          - #edges
+          - #features
+          - #classes
+        * - 70,000
+          - 75
+          - ~1,393.0
+          - 1
+          - 10
     """
 
     url = 'https://data.pyg.org/datasets/MNISTSuperpixels.zip'
