@@ -2,7 +2,6 @@ import logging
 import math
 import sys
 import time
-import warnings
 from typing import Any, Dict, Optional
 
 import torch
@@ -10,19 +9,10 @@ import torch
 from torch_geometric.data.makedirs import makedirs
 from torch_geometric.graphgym import register
 from torch_geometric.graphgym.config import cfg
+from torch_geometric.graphgym.imports import Callback, pl
 from torch_geometric.graphgym.utils.device import get_current_gpu_usage
 from torch_geometric.graphgym.utils.io import dict_to_json, dict_to_tb
 
-try:
-    import pytorch_lightning as pl
-    from pytorch_lightning import Callback
-
-except ImportError:
-    pl = None
-    Callback = object
-    warnings.warn("Please install 'pytorch_lightning' for using the GraphGym "
-                  "experiment manager via 'pip install pytorch_lightning'")
-
 
 def set_printing():
     """
@@ -324,7 +314,7 @@ class LoggerCallback(Callback):
         batch: Any,
         batch_idx: int,
         unused: int = 0,
-    ) -> None:
+    ):
         stats = self._get_stats(self._train_epoch_start_time, outputs, trainer)
         self.train_logger.update_stats(**stats)
 
@@ -335,8 +325,8 @@ class LoggerCallback(Callback):
         outputs: Optional[Dict[str, Any]],
         batch: Any,
         batch_idx: int,
-        dataloader_idx: int,
-    ) -> None:
+        dataloader_idx: int = 0,
+    ):
         stats = self._get_stats(self._val_epoch_start_time, outputs, trainer)
         self.val_logger.update_stats(**stats)
 
@@ -347,8 +337,8 @@ class LoggerCallback(Callback):
         outputs: Optional[Dict[str, Any]],
         batch: Any,
         batch_idx: int,
-        dataloader_idx: int,
-    ) -> None:
+        dataloader_idx: int = 0,
+    ):
         stats = self._get_stats(self._test_epoch_start_time, outputs, trainer)
         self.test_logger.update_stats(**stats)
 
