@@ -1,11 +1,12 @@
-from .meta import MetaLayer
 from .reshape import Reshape
 from .sequential import Sequential
 from .data_parallel import DataParallel
 from .to_hetero_transformer import to_hetero
 from .to_hetero_with_bases_transformer import to_hetero_with_bases
 from .to_fixed_size_transformer import to_fixed_size
-from .encoding import PositionalEncoding
+from .encoding import PositionalEncoding, TemporalEncoding
+from .model_hub import PyGModelHubMixin
+from .summary import summary
 
 from .aggr import *  # noqa
 from .conv import *  # noqa
@@ -14,11 +15,11 @@ from .glob import *  # noqa
 from .norm import *  # noqa
 from .unpool import *  # noqa
 from .dense import *  # noqa
+from .kge import *  # noqa
 from .models import *  # noqa
 from .functional import *  # noqa
 
 __all__ = [
-    'MetaLayer',
     'Reshape',
     'Sequential',
     'DataParallel',
@@ -26,4 +27,7 @@ __all__ = [
     'to_hetero_with_bases',
     'to_fixed_size',
     'PositionalEncoding',
+    'TemporalEncoding',
+    'PyGModelHubMixin',
+    'summary',
 ]
