@@ -13,12 +13,16 @@ from .basic import (
 )
 from .quantile import MedianAggregation, QuantileAggregation
 from .lstm import LSTMAggregation
+from .gru import GRUAggregation
 from .set2set import Set2Set
 from .scaler import DegreeScalerAggregation
 from .equilibrium import EquilibriumAggregation
 from .sort import SortAggregation
 from .gmt import GraphMultisetTransformer
 from .attention import AttentionalAggregation
+from .mlp import MLPAggregation
+from .deep_sets import DeepSetsAggregation
+from .set_transformer import SetTransformerAggregation
 
 __all__ = classes = [
     'Aggregation',
@@ -35,10 +39,14 @@ __all__ = classes = [
     'MedianAggregation',
     'QuantileAggregation',
     'LSTMAggregation',
+    'GRUAggregation',
     'Set2Set',
     'DegreeScalerAggregation',
     'SortAggregation',
     'GraphMultisetTransformer',
     'AttentionalAggregation',
     'EquilibriumAggregation',
+    'MLPAggregation',
+    'DeepSetsAggregation',
+    'SetTransformerAggregation',
 ]
