@@ -3,15 +3,13 @@ from typing import List, Optional, Tuple
 import torch
 from torch import Tensor
 from torch.nn import Parameter
-from torch_scatter import scatter
-from torch_sparse import SparseTensor, fill_diag, matmul
 
 from torch_geometric.nn.conv import MessagePassing
 from torch_geometric.nn.conv.gcn_conv import gcn_norm
 from torch_geometric.nn.dense.linear import Linear
 from torch_geometric.nn.inits import zeros
-from torch_geometric.typing import Adj, OptTensor
-from torch_geometric.utils import add_remaining_self_loops
+from torch_geometric.typing import Adj, OptTensor, SparseTensor, torch_sparse
+from torch_geometric.utils import add_remaining_self_loops, scatter, spmm
 
 
 class EGConv(MessagePassing):
@@ -115,6 +113,7 @@ class EGConv(MessagePassing):
         self.reset_parameters()
 
     def reset_parameters(self):
+        super().reset_parameters()
         self.bases_lin.reset_parameters()
         self.comb_lin.reset_parameters()
         zeros(self.bias)
@@ -122,7 +121,6 @@ class EGConv(MessagePassing):
         self._cached_edge_index = None
 
     def forward(self, x: Tensor, edge_index: Adj) -> Tensor:
-        """"""
         symnorm_weight: OptTensor = None
         if "symnorm" in self.aggregators:
             if isinstance(edge_index, Tensor):
@@ -164,7 +162,7 @@ class EGConv(MessagePassing):
                 if self.cached and cache is not None:
                     edge_index = cache
                 else:
-                    edge_index = fill_diag(edge_index, 1.0)
+                    edge_index = torch_sparse.fill_diag(edge_index, 1.0)
                     if self.cached:
                         self._cached_adj_t = edge_index
 
@@ -207,16 +205,16 @@ class EGConv(MessagePassing):
             if aggr == 'symnorm':
                 assert symnorm_weight is not None
                 out = scatter(inputs * symnorm_weight.view(-1, 1), index, 0,
-                              None, dim_size, reduce='sum')
+                              dim_size, reduce='sum')
             elif aggr == 'var' or aggr == 'std':
-                mean = scatter(inputs, index, 0, None, dim_size, reduce='mean')
-                mean_squares = scatter(inputs * inputs, index, 0, None,
-                                       dim_size, reduce='mean')
+                mean = scatter(inputs, index, 0, dim_size, reduce='mean')
+                mean_squares = scatter(inputs * inputs, index, 0, dim_size,
+                                       reduce='mean')
                 out = mean_squares - mean * mean
                 if aggr == 'std':
                     out = out.clamp(min=1e-5).sqrt()
             else:
-                out = scatter(inputs, index, 0, None, dim_size, reduce=aggr)
+                out = scatter(inputs, index, 0, dim_size, reduce=aggr)
 
             outs.append(out)
 
@@ -230,15 +228,15 @@ class EGConv(MessagePassing):
         outs = []
         for aggr in self.aggregators:
             if aggr == 'symnorm':
-                out = matmul(adj_t, x, reduce='sum')
+                out = spmm(adj_t, x, reduce='sum')
             elif aggr in ['var', 'std']:
-                mean = matmul(adj_t_2, x, reduce='mean')
-                mean_sq = matmul(adj_t_2, x * x, reduce='mean')
+                mean = spmm(adj_t_2, x, reduce='mean')
+                mean_sq = spmm(adj_t_2, x * x, reduce='mean')
                 out = mean_sq - mean * mean
                 if aggr == 'std':
                     out = torch.sqrt(out.relu_() + 1e-5)
             else:
-                out = matmul(adj_t_2, x, reduce=aggr)
+                out = spmm(adj_t_2, x, reduce=aggr)
 
             outs.append(out)
 
