@@ -1,15 +1,15 @@
 from typing import Union
-from torch_geometric.typing import PairTensor, Adj
 
 import torch
+import torch.nn.functional as F
 from torch import Tensor
 from torch.nn import Parameter
-import torch.nn.functional as F
-from torch_sparse import SparseTensor, set_diag
-from torch_geometric.nn.inits import normal
+
 from torch_geometric.nn.conv import MessagePassing
 from torch_geometric.nn.dense.linear import Linear
-from torch_geometric.utils import remove_self_loops, add_self_loops
+from torch_geometric.nn.inits import normal
+from torch_geometric.typing import Adj, PairTensor, SparseTensor, torch_sparse
+from torch_geometric.utils import add_self_loops, remove_self_loops
 
 
 class FeaStConv(MessagePassing):
@@ -39,11 +39,20 @@ class FeaStConv(MessagePassing):
             an additive bias. (default: :obj:`True`)
         **kwargs (optional): Additional arguments of
             :class:`torch_geometric.nn.conv.MessagePassing`.
+
+    Shapes:
+        - **input:**
+          node features :math:`(|\mathcal{V}|, F_{in})` or
+          :math:`((|\mathcal{V_s}|, F_{in}), (|\mathcal{V_t}|, F_{in}))`
+          if bipartite,
+          edge indices :math:`(2, |\mathcal{E}|)`
+        - **output:** node features :math:`(|\mathcal{V}|, F_{out})` or
+          :math:`(|\mathcal{V_t}|, F_{out})` if bipartite
     """
     def __init__(self, in_channels: int, out_channels: int, heads: int = 1,
                  add_self_loops: bool = True, bias: bool = True, **kwargs):
         kwargs.setdefault('aggr', 'mean')
-        super(FeaStConv, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self.in_channels = in_channels
         self.out_channels = out_channels
@@ -64,13 +73,13 @@ class FeaStConv(MessagePassing):
         self.reset_parameters()
 
     def reset_parameters(self):
+        super().reset_parameters()
         self.lin.reset_parameters()
         self.u.reset_parameters()
         normal(self.c, mean=0, std=0.1)
         normal(self.bias, mean=0, std=0.1)
 
     def forward(self, x: Union[Tensor, PairTensor], edge_index: Adj) -> Tensor:
-        """"""
         if isinstance(x, Tensor):
             x: PairTensor = (x, x)
 
@@ -80,13 +89,13 @@ class FeaStConv(MessagePassing):
                 edge_index, _ = add_self_loops(edge_index,
                                                num_nodes=x[1].size(0))
             elif isinstance(edge_index, SparseTensor):
-                edge_index = set_diag(edge_index)
+                edge_index = torch_sparse.set_diag(edge_index)
 
         # propagate_type: (x: PairTensor)
         out = self.propagate(edge_index, x=x, size=None)
 
         if self.bias is not None:
-            out += self.bias
+            out = out + self.bias
 
         return out
 
@@ -96,7 +105,6 @@ class FeaStConv(MessagePassing):
         x_j = self.lin(x_j).view(x_j.size(0), self.heads, -1)
         return (x_j * q.view(-1, self.heads, 1)).sum(dim=1)
 
-    def __repr__(self):
-        return '{}({}, {}, heads={})'.format(self.__class__.__name__,
-                                             self.in_channels,
-                                             self.out_channels, self.heads)
+    def __repr__(self) -> str:
+        return (f'{self.__class__.__name__}({self.in_channels}, '
+                f'{self.out_channels}, heads={self.heads})')
