@@ -9,15 +9,20 @@ from torch.nn import (
     ReLU,
     Sequential,
 )
-from torch_sparse import SparseTensor
 
 from torch_geometric.nn.aggr import Aggregation, MultiAggregation
 from torch_geometric.nn.conv import MessagePassing
 from torch_geometric.nn.dense.linear import Linear
+from torch_geometric.nn.inits import reset
 from torch_geometric.nn.norm import MessageNorm
-from torch_geometric.typing import Adj, OptPairTensor, OptTensor, Size
-
-from ..inits import reset
+from torch_geometric.typing import (
+    Adj,
+    OptPairTensor,
+    OptTensor,
+    Size,
+    SparseTensor,
+)
+from torch_geometric.utils import is_torch_sparse_tensor, to_edge_index
 
 
 class MLP(Sequential):
@@ -68,7 +73,7 @@ class GENConv(MessagePassing):
             A tuple corresponds to the sizes of source and target
             dimensionalities.
         out_channels (int): Size of each output sample.
-        aggr (string or Aggregation, optional): The aggregation scheme to use.
+        aggr (str or Aggregation, optional): The aggregation scheme to use.
             Any aggregation of :obj:`torch_geometric.nn.aggr` can be used,
             (:obj:`"softmax"`, :obj:`"powermean"`, :obj:`"add"`, :obj:`"mean"`,
             :obj:`max`). (default: :obj:`"softmax"`)
@@ -184,8 +189,8 @@ class GENConv(MessagePassing):
             self.msg_norm = MessageNorm(learn_msg_scale)
 
     def reset_parameters(self):
+        super().reset_parameters()
         reset(self.mlp)
-        self.aggr_module.reset_parameters()
         if hasattr(self, 'msg_norm'):
             self.msg_norm.reset_parameters()
         if hasattr(self, 'lin_src'):
@@ -199,7 +204,7 @@ class GENConv(MessagePassing):
 
     def forward(self, x: Union[Tensor, OptPairTensor], edge_index: Adj,
                 edge_attr: OptTensor = None, size: Size = None) -> Tensor:
-        """"""
+
         if isinstance(x, Tensor):
             x: OptPairTensor = (x, x)
 
@@ -208,6 +213,10 @@ class GENConv(MessagePassing):
 
         if isinstance(edge_index, SparseTensor):
             edge_attr = edge_index.storage.value()
+        elif is_torch_sparse_tensor(edge_index):
+            _, value = to_edge_index(edge_index)
+            if value.dim() > 1 or not value.all():
+                edge_attr = value
 
         if edge_attr is not None and hasattr(self, 'lin_edge'):
             edge_attr = self.lin_edge(edge_attr)
@@ -223,7 +232,9 @@ class GENConv(MessagePassing):
             out = self.lin_aggr_out(out)
 
         if hasattr(self, 'msg_norm'):
-            out = self.msg_norm(x[1] if x[1] is not None else x[0], out)
+            h = x[1] if x[1] is not None else x[0]
+            assert h is not None
+            out = self.msg_norm(h, out)
 
         x_dst = x[1]
         if x_dst is not None:
