@@ -20,44 +20,54 @@ from uuid import uuid1
 import torch
 from torch import Tensor
 from torch.utils.hooks import RemovableHandle
-from torch_scatter import gather_csr
-from torch_sparse import SparseTensor
 
 from torch_geometric.nn.aggr import Aggregation, MultiAggregation
-from torch_geometric.nn.resolver import aggregation_resolver as aggr_resolver
-from torch_geometric.typing import Adj, Size
-from torch_geometric.utils import is_sparse, is_torch_sparse_tensor
-
-from .utils.helpers import expand_left
-from .utils.inspector import Inspector, func_body_repr, func_header_repr
-from .utils.jit import class_from_module_repr
-from .utils.typing import (
+from torch_geometric.nn.conv.utils.inspector import (
+    Inspector,
+    func_body_repr,
+    func_header_repr,
+)
+from torch_geometric.nn.conv.utils.jit import class_from_module_repr
+from torch_geometric.nn.conv.utils.typing import (
     parse_types,
     resolve_types,
     sanitize,
     split_types_repr,
 )
+from torch_geometric.nn.resolver import aggregation_resolver as aggr_resolver
+from torch_geometric.typing import Adj, Size, SparseTensor
+from torch_geometric.utils import (
+    is_sparse,
+    is_torch_sparse_tensor,
+    to_edge_index,
+)
+from torch_geometric.utils.sparse import ptr2index
 
 FUSE_AGGRS = {'add', 'sum', 'mean', 'min', 'max'}
 
 
+def ptr2ind(ptr: Tensor) -> Tensor:
+    ind = torch.arange(ptr.numel() - 1, device=ptr.device)
+    return ind.repeat_interleave(ptr[1:] - ptr[:-1])
+
+
 class MessagePassing(torch.nn.Module):
     r"""Base class for creating message passing layers of the form
 
     .. math::
         \mathbf{x}_i^{\prime} = \gamma_{\mathbf{\Theta}} \left( \mathbf{x}_i,
-        \square_{j \in \mathcal{N}(i)} \, \phi_{\mathbf{\Theta}}
+        \bigoplus_{j \in \mathcal{N}(i)} \, \phi_{\mathbf{\Theta}}
         \left(\mathbf{x}_i, \mathbf{x}_j,\mathbf{e}_{j,i}\right) \right),
 
-    where :math:`\square` denotes a differentiable, permutation invariant
+    where :math:`\bigoplus` denotes a differentiable, permutation invariant
     function, *e.g.*, sum, mean, min, max or mul, and
     :math:`\gamma_{\mathbf{\Theta}}` and :math:`\phi_{\mathbf{\Theta}}` denote
     differentiable functions such as MLPs.
-    See `here <https://pytorch-geometric.readthedocs.io/en/latest/notes/
+    See `here <https://pytorch-geometric.readthedocs.io/en/latest/tutorial/
     create_gnn.html>`__ for the accompanying tutorial.
 
     Args:
-        aggr (string or list or Aggregation, optional): The aggregation scheme
+        aggr (str or [str] or Aggregation, optional): The aggregation scheme
             to use, *e.g.*, :obj:`"add"`, :obj:`"sum"` :obj:`"mean"`,
             :obj:`"min"`, :obj:`"max"` or :obj:`"mul"`.
             In addition, can be any
@@ -71,7 +81,7 @@ class MessagePassing(torch.nn.Module):
         aggr_kwargs (Dict[str, Any], optional): Arguments passed to the
             respective aggregation function in case it gets automatically
             resolved. (default: :obj:`None`)
-        flow (string, optional): The flow direction of message passing
+        flow (str, optional): The flow direction of message passing
             (:obj:`"source_to_target"` or :obj:`"target_to_source"`).
             (default: :obj:`"source_to_target"`)
         node_dim (int, optional): The axis along which to propagate.
@@ -150,12 +160,12 @@ class MessagePassing(torch.nn.Module):
         self.inspector.inspect(self.update, pop_first=True)
         self.inspector.inspect(self.edge_update)
 
-        self.__user_args__ = self.inspector.keys(
+        self._user_args = self.inspector.keys(
             ['message', 'aggregate', 'update']).difference(self.special_args)
-        self.__fused_user_args__ = self.inspector.keys(
+        self._fused_user_args = self.inspector.keys(
             ['message_and_aggregate', 'update']).difference(self.special_args)
-        self.__edge_user_args__ = self.inspector.keys(
-            ['edge_update']).difference(self.special_args)
+        self._edge_user_args = self.inspector.keys(['edge_update']).difference(
+            self.special_args)
 
         # Support for "fused" message passing.
         self.fuse = self.inspector.implements('message_and_aggregate')
@@ -180,7 +190,16 @@ class MessagePassing(torch.nn.Module):
         self._edge_update_forward_pre_hooks = OrderedDict()
         self._edge_update_forward_hooks = OrderedDict()
 
-    def __check_input__(self, edge_index, size):
+    def reset_parameters(self):
+        r"""Resets all learnable parameters of the module."""
+        if self.aggr_module is not None:
+            self.aggr_module.reset_parameters()
+
+    def forward(self, *args, **kwargs) -> Any:
+        r"""Runs the forward pass of the module."""
+        pass
+
+    def _check_input(self, edge_index, size):
         the_size: List[Optional[int]] = [None, None]
 
         if is_sparse(edge_index):
@@ -218,7 +237,7 @@ class MessagePassing(torch.nn.Module):
              'shape `[2, num_messages]`, `torch_sparse.SparseTensor` or '
              '`torch.sparse.Tensor` for argument `edge_index`.'))
 
-    def __set_size__(self, size: List[Optional[int]], dim: int, src: Tensor):
+    def _set_size(self, size: List[Optional[int]], dim: int, src: Tensor):
         the_size = size[dim]
         if the_size is None:
             size[dim] = src.size(self.node_dim)
@@ -227,10 +246,24 @@ class MessagePassing(torch.nn.Module):
                 (f'Encountered tensor with size {src.size(self.node_dim)} in '
                  f'dimension {self.node_dim}, but expected size {the_size}.'))
 
-    def __lift__(self, src, edge_index, dim):
+    def _lift(self, src, edge_index, dim):
         if is_torch_sparse_tensor(edge_index):
             assert dim == 0 or dim == 1
-            index = edge_index._indices()[1 - dim]
+            if edge_index.layout == torch.sparse_coo:
+                index = edge_index._indices()[1 - dim]
+            elif edge_index.layout == torch.sparse_csr:
+                if dim == 0:
+                    index = edge_index.col_indices()
+                else:
+                    index = ptr2index(edge_index.crow_indices())
+            elif edge_index.layout == torch.sparse_csc:
+                if dim == 0:
+                    index = ptr2index(edge_index.ccol_indices())
+                else:
+                    index = edge_index.row_indices()
+            else:
+                raise ValueError(f"Unsupported sparse tensor layout "
+                                 f"(got '{edge_index.layout}')")
             return src.index_select(self.node_dim, index)
 
         elif isinstance(edge_index, Tensor):
@@ -238,12 +271,15 @@ class MessagePassing(torch.nn.Module):
                 index = edge_index[dim]
                 return src.index_select(self.node_dim, index)
             except (IndexError, RuntimeError) as e:
-                if 'CUDA' in str(e):
-                    raise ValueError(
-                        f"Encountered a CUDA error. Please ensure that all "
-                        f"indices in 'edge_index' point to valid indices "
-                        f"in the interval [0, {src.size(self.node_dim)}) in "
-                        f"your node feature matrix and try again.")
+                if index.min() < 0 or index.max() >= src.size(self.node_dim):
+                    raise IndexError(
+                        f"Encountered an index error. Please ensure that all "
+                        f"indices in 'edge_index' point to valid indices in "
+                        f"the interval [0, {src.size(self.node_dim) - 1}] "
+                        f"(got interval "
+                        f"[{int(index.min())}, {int(index.max())}])")
+                else:
+                    raise e
 
                 if index.numel() > 0 and index.min() < 0:
                     raise ValueError(
@@ -266,20 +302,19 @@ class MessagePassing(torch.nn.Module):
                 raise e
 
         elif isinstance(edge_index, SparseTensor):
-            if dim == 1:
-                rowptr = edge_index.storage.rowptr()
-                rowptr = expand_left(rowptr, dim=self.node_dim, dims=src.dim())
-                return gather_csr(src, rowptr)
-            elif dim == 0:
+            if dim == 0:
                 col = edge_index.storage.col()
                 return src.index_select(self.node_dim, col)
+            elif dim == 1:
+                row = edge_index.storage.row()
+                return src.index_select(self.node_dim, row)
 
         raise ValueError(
             ('`MessagePassing.propagate` only supports integer tensors of '
              'shape `[2, num_messages]`, `torch_sparse.SparseTensor` '
              'or `torch.sparse.Tensor` for argument `edge_index`.'))
 
-    def __collect__(self, args, edge_index, size, kwargs):
+    def _collect(self, args, edge_index, size, kwargs):
         i, j = (1, 0) if self.flow == 'source_to_target' else (0, 1)
 
         out = {}
@@ -293,23 +328,17 @@ class MessagePassing(torch.nn.Module):
                 if isinstance(data, (tuple, list)):
                     assert len(data) == 2
                     if isinstance(data[1 - dim], Tensor):
-                        self.__set_size__(size, 1 - dim, data[1 - dim])
+                        self._set_size(size, 1 - dim, data[1 - dim])
                     data = data[dim]
 
                 if isinstance(data, Tensor):
-                    self.__set_size__(size, dim, data)
-                    data = self.__lift__(data, edge_index, dim)
+                    self._set_size(size, dim, data)
+                    data = self._lift(data, edge_index, dim)
 
                 out[arg] = data
 
         if is_torch_sparse_tensor(edge_index):
-            if edge_index.requires_grad:
-                edge_index = edge_index.coalesce()
-                indices = edge_index.indices()
-                values = edge_index.values()
-            else:
-                indices = edge_index._indices()
-                values = edge_index._values()
+            indices, values = to_edge_index(edge_index)
             out['adj_t'] = edge_index
             out['edge_index'] = None
             out['edge_index_i'] = indices[0]
@@ -318,7 +347,7 @@ class MessagePassing(torch.nn.Module):
             if out.get('edge_weight', None) is None:
                 out['edge_weight'] = values
             if out.get('edge_attr', None) is None:
-                out['edge_attr'] = values
+                out['edge_attr'] = None if values.dim() == 1 else values
             if out.get('edge_type', None) is None:
                 out['edge_type'] = values
 
@@ -354,31 +383,32 @@ class MessagePassing(torch.nn.Module):
         r"""The initial call to start propagating messages.
 
         Args:
-            edge_index (Tensor or SparseTensor): A :obj:`torch.LongTensor`, a
-                :obj:`torch_sparse.SparseTensor` or a
-                :obj:`torch.sparse.Tensor` that defines the underlying
+            edge_index (torch.Tensor or SparseTensor): A :class:`torch.Tensor`,
+                a :class:`torch_sparse.SparseTensor` or a
+                :class:`torch.sparse.Tensor` that defines the underlying
                 graph connectivity/message passing flow.
                 :obj:`edge_index` holds the indices of a general (sparse)
                 assignment matrix of shape :obj:`[N, M]`.
-                If :obj:`edge_index` is of type :obj:`torch.LongTensor`, its
-                shape must be defined as :obj:`[2, num_messages]`, where
-                messages from nodes in :obj:`edge_index[0]` are sent to
-                nodes in :obj:`edge_index[1]`
+                If :obj:`edge_index` is a :obj:`torch.Tensor`, its :obj:`dtype`
+                should be :obj:`torch.long` and its shape needs to be defined
+                as :obj:`[2, num_messages]` where messages from nodes in
+                :obj:`edge_index[0]` are sent to nodes in :obj:`edge_index[1]`
                 (in case :obj:`flow="source_to_target"`).
-                If :obj:`edge_index` is of type
-                :obj:`torch_sparse.SparseTensor` or :obj:`torch.sparse.Tensor`,
-                its sparse indices :obj:`(row, col)` should relate to
-                :obj:`row = edge_index[1]` and :obj:`col = edge_index[0]`.
+                If :obj:`edge_index` is a :class:`torch_sparse.SparseTensor` or
+                a :class:`torch.sparse.Tensor`, its sparse indices
+                :obj:`(row, col)` should relate to :obj:`row = edge_index[1]`
+                and :obj:`col = edge_index[0]`.
                 The major difference between both formats is that we need to
                 input the *transposed* sparse adjacency matrix into
-                :func:`propagate`.
-            size (tuple, optional): The size :obj:`(N, M)` of the assignment
-                matrix in case :obj:`edge_index` is a :obj:`LongTensor`.
+                :meth:`propagate`.
+            size ((int, int), optional): The size :obj:`(N, M)` of the
+                assignment matrix in case :obj:`edge_index` is a
+                :class:`torch.Tensor`.
                 If set to :obj:`None`, the size will be automatically inferred
                 and assumed to be quadratic.
                 This argument is ignored in case :obj:`edge_index` is a
-                :obj:`torch_sparse.SparseTensor` or
-                a :obj:`torch.sparse.Tensor`. (default: :obj:`None`)
+                :class:`torch_sparse.SparseTensor` or
+                a :class:`torch.sparse.Tensor`. (default: :obj:`None`)
             **kwargs: Any additional data which is needed to construct and
                 aggregate messages, and to update node embeddings.
         """
@@ -389,12 +419,12 @@ class MessagePassing(torch.nn.Module):
             if res is not None:
                 edge_index, size, kwargs = res
 
-        size = self.__check_input__(edge_index, size)
+        size = self._check_input(edge_index, size)
 
         # Run "fused" message and aggregation (if applicable).
         if is_sparse(edge_index) and self.fuse and not self.explain:
-            coll_dict = self.__collect__(self.__fused_user_args__, edge_index,
-                                         size, kwargs)
+            coll_dict = self._collect(self._fused_user_args, edge_index, size,
+                                      kwargs)
 
             msg_aggr_kwargs = self.inspector.distribute(
                 'message_and_aggregate', coll_dict)
@@ -413,7 +443,7 @@ class MessagePassing(torch.nn.Module):
 
         else:  # Otherwise, run both functions in separation.
             if decomposed_layers > 1:
-                user_args = self.__user_args__
+                user_args = self._user_args
                 decomp_args = {a[:-2] for a in user_args if a[-2:] == '_j'}
                 decomp_kwargs = {
                     a: kwargs[a].chunk(decomposed_layers, -1)
@@ -426,8 +456,8 @@ class MessagePassing(torch.nn.Module):
                     for arg in decomp_args:
                         kwargs[arg] = decomp_kwargs[arg][i]
 
-                coll_dict = self.__collect__(self.__user_args__, edge_index,
-                                             size, kwargs)
+                coll_dict = self._collect(self._user_args, edge_index, size,
+                                          kwargs)
 
                 msg_kwargs = self.inspector.distribute('message', coll_dict)
                 for hook in self._message_forward_pre_hooks.values():
@@ -479,10 +509,10 @@ class MessagePassing(torch.nn.Module):
         graph.
 
         Args:
-            edge_index (Tensor or SparseTensor): A :obj:`torch.LongTensor`, a
-                :obj:`torch_sparse.SparseTensor` or
-                a :obj:`torch.sparse.Tensor` that defines the underlying
-                graph connectivity/message passing flow.
+            edge_index (torch.Tensor or SparseTensor): A :obj:`torch.Tensor`, a
+                :class:`torch_sparse.SparseTensor` or a
+                :class:`torch.sparse.Tensor` that defines the underlying graph
+                connectivity/message passing flow.
                 See :meth:`propagate` for more information.
             **kwargs: Any additional data which is needed to compute or update
                 features for each edge in the graph.
@@ -492,10 +522,10 @@ class MessagePassing(torch.nn.Module):
             if res is not None:
                 edge_index, kwargs = res
 
-        size = self.__check_input__(edge_index, size=None)
+        size = self._check_input(edge_index, size=None)
 
-        coll_dict = self.__collect__(self.__edge_user_args__, edge_index, size,
-                                     kwargs)
+        coll_dict = self._collect(self._edge_user_args, edge_index, size,
+                                  kwargs)
 
         edge_kwargs = self.inspector.distribute('edge_update', coll_dict)
         out = self.edge_update(**edge_kwargs)
@@ -532,7 +562,7 @@ class MessagePassing(torch.nn.Module):
 
         self._explain = explain
         self.inspector.inspect(self.explain_message, pop_first=True)
-        self.__user_args__ = self.inspector.keys(methods).difference(
+        self._user_args = self.inspector.keys(methods).difference(
             self.special_args)
 
     def explain_message(self, inputs: Tensor, size_i: int) -> Tensor:
@@ -566,7 +596,7 @@ class MessagePassing(torch.nn.Module):
                   ptr: Optional[Tensor] = None,
                   dim_size: Optional[int] = None) -> Tensor:
         r"""Aggregates messages from neighbors as
-        :math:`\square_{j \in \mathcal{N}(i)}`.
+        :math:`\bigoplus_{j \in \mathcal{N}(i)}`.
 
         Takes in the output of message computation as first argument and any
         argument which was initially passed to :meth:`propagate`.
@@ -745,9 +775,9 @@ class MessagePassing(torch.nn.Module):
         jittable module.
 
         Args:
-            typing (string, optional): If given, will generate a concrete
-                instance with :meth:`forward` types based on :obj:`typing`,
-                *e.g.*: :obj:`"(Tensor, Optional[Tensor]) -> Tensor"`.
+            typing (str, optional): If given, will generate a concrete instance
+                with :meth:`forward` types based on :obj:`typing`, *e.g.*,
+                :obj:`"(Tensor, Optional[Tensor]) -> Tensor"`.
         """
         try:
             from jinja2 import Template
@@ -810,11 +840,11 @@ class MessagePassing(torch.nn.Module):
         if str(edge_updater_return_type)[:6] == '<class':
             edge_updater_return_type = edge_updater_return_type.__name__
 
-        # Parse `__collect__()` types to format `{arg:1, type1, ...}`.
+        # Parse `_collect()` types to format `{arg:1, type1, ...}`.
         collect_types = self.inspector.types(
             ['message', 'aggregate', 'update'])
 
-        # Parse `__collect__()` types to format `{arg:1, type1, ...}`,
+        # Parse `_collect()` types to format `{arg:1, type1, ...}`,
         # specific to the argument used for edge updates.
         edge_collect_types = self.inspector.types(['edge_update'])
 
@@ -848,8 +878,8 @@ class MessagePassing(torch.nn.Module):
             prop_return_type=prop_return_type,
             fuse=self.fuse,
             collect_types=collect_types,
-            user_args=self.__user_args__,
-            edge_user_args=self.__edge_user_args__,
+            user_args=self._user_args,
+            edge_user_args=self._edge_user_args,
             forward_header=forward_header,
             forward_types=forward_types,
             forward_body=forward_body,
@@ -861,7 +891,7 @@ class MessagePassing(torch.nn.Module):
             edge_update_args=self.inspector.keys(['edge_update']),
             edge_updater_types=edge_updater_types,
             edge_updater_return_type=edge_updater_return_type,
-            check_input=inspect.getsource(self.__check_input__)[:-1],
+            check_input=inspect.getsource(self._check_input)[:-1],
         )
         # Instantiate a class from the rendered JIT module representation.
         cls = class_from_module_repr(cls_name, jit_module_repr)
