@@ -1,12 +1,13 @@
-from typing import Union, Tuple, Callable
-from torch_geometric.typing import OptTensor, OptPairTensor, Adj, Size
+from typing import Callable, Tuple, Union
 
 import torch
 from torch import Tensor
 from torch.nn import Parameter
-from torch_geometric.nn.inits import reset, zeros
+
 from torch_geometric.nn.conv import MessagePassing
 from torch_geometric.nn.dense.linear import Linear
+from torch_geometric.nn.inits import reset, zeros
+from torch_geometric.typing import Adj, OptPairTensor, OptTensor, Size
 
 
 class NNConv(MessagePassing):
@@ -37,7 +38,7 @@ class NNConv(MessagePassing):
             num_edge_features]` to shape
             :obj:`[-1, in_channels * out_channels]`, *e.g.*, defined by
             :class:`torch.nn.Sequential`.
-        aggr (string, optional): The aggregation scheme to use
+        aggr (str, optional): The aggregation scheme to use
             (:obj:`"add"`, :obj:`"mean"`, :obj:`"max"`).
             (default: :obj:`"add"`)
         root_weight (bool, optional): If set to :obj:`False`, the layer will
@@ -47,11 +48,21 @@ class NNConv(MessagePassing):
             an additive bias. (default: :obj:`True`)
         **kwargs (optional): Additional arguments of
             :class:`torch_geometric.nn.conv.MessagePassing`.
+
+    Shapes:
+        - **input:**
+          node features :math:`(|\mathcal{V}|, F_{in})` or
+          :math:`((|\mathcal{V_s}|, F_{s}), (|\mathcal{V_t}|, F_{t}))`
+          if bipartite,
+          edge indices :math:`(2, |\mathcal{E}|)`,
+          edge features :math:`(|\mathcal{E}|, D)` *(optional)*
+        - **output:** node features :math:`(|\mathcal{V}|, F_{out})` or
+          :math:`(|\mathcal{V}_t|, F_{out})` if bipartite
     """
     def __init__(self, in_channels: Union[int, Tuple[int, int]],
                  out_channels: int, nn: Callable, aggr: str = 'add',
                  root_weight: bool = True, bias: bool = True, **kwargs):
-        super(NNConv, self).__init__(aggr=aggr, **kwargs)
+        super().__init__(aggr=aggr, **kwargs)
 
         self.in_channels = in_channels
         self.out_channels = out_channels
@@ -75,6 +86,7 @@ class NNConv(MessagePassing):
         self.reset_parameters()
 
     def reset_parameters(self):
+        super().reset_parameters()
         reset(self.nn)
         if self.root_weight:
             self.lin.reset_parameters()
@@ -82,7 +94,7 @@ class NNConv(MessagePassing):
 
     def forward(self, x: Union[Tensor, OptPairTensor], edge_index: Adj,
                 edge_attr: OptTensor = None, size: Size = None) -> Tensor:
-        """"""
+
         if isinstance(x, Tensor):
             x: OptPairTensor = (x, x)
 
@@ -91,10 +103,10 @@ class NNConv(MessagePassing):
 
         x_r = x[1]
         if x_r is not None and self.root_weight:
-            out += self.lin(x_r)
+            out = out + self.lin(x_r)
 
         if self.bias is not None:
-            out += self.bias
+            out = out + self.bias
 
         return out
 
@@ -103,11 +115,6 @@ class NNConv(MessagePassing):
         weight = weight.view(-1, self.in_channels_l, self.out_channels)
         return torch.matmul(x_j.unsqueeze(1), weight).squeeze(1)
 
-    def __repr__(self):
-        return '{}({}, {}, aggr="{}", nn={})'.format(self.__class__.__name__,
-                                                     self.in_channels,
-                                                     self.out_channels,
-                                                     self.aggr, self.nn)
-
-
-ECConv = NNConv
+    def __repr__(self) -> str:
+        return (f'{self.__class__.__name__}({self.in_channels}, '
+                f'{self.out_channels}, aggr={self.aggr}, nn={self.nn})')
