@@ -5,10 +5,9 @@ from torch.nn import Parameter, Sigmoid
 
 from torch_geometric.nn.conv import MessagePassing
 from torch_geometric.nn.dense.linear import Linear
+from torch_geometric.nn.inits import zeros
 from torch_geometric.typing import Adj, PairTensor
 
-from ..inits import zeros
-
 
 class ResGatedGraphConv(MessagePassing):
     r"""The residual gated graph convolutional operator from the
@@ -89,6 +88,7 @@ class ResGatedGraphConv(MessagePassing):
         self.reset_parameters()
 
     def reset_parameters(self):
+        super().reset_parameters()
         self.lin_key.reset_parameters()
         self.lin_query.reset_parameters()
         self.lin_value.reset_parameters()
@@ -98,7 +98,6 @@ class ResGatedGraphConv(MessagePassing):
             zeros(self.bias)
 
     def forward(self, x: Union[Tensor, PairTensor], edge_index: Adj) -> Tensor:
-        """"""
         if isinstance(x, Tensor):
             x: PairTensor = (x, x)
 
