@@ -1,20 +1,27 @@
-from .linear import Linear
+from .linear import Linear, HeteroLinear, HeteroDictLinear
+from .dense_gat_conv import DenseGATConv
 from .dense_sage_conv import DenseSAGEConv
 from .dense_gcn_conv import DenseGCNConv
 from .dense_graph_conv import DenseGraphConv
 from .dense_gin_conv import DenseGINConv
 from .diff_pool import dense_diff_pool
 from .mincut_pool import dense_mincut_pool
+from .dmon_pool import DMoNPooling
 
 __all__ = [
     'Linear',
+    'HeteroLinear',
+    'HeteroDictLinear',
     'DenseGCNConv',
     'DenseGINConv',
     'DenseGraphConv',
     'DenseSAGEConv',
+    'DenseGATConv',
     'dense_diff_pool',
     'dense_mincut_pool',
+    'DMoNPooling',
 ]
 
-conv_classes = __all__[:4]
-pool_classes = __all__[4:]
+lin_classes = __all__[:3]
+conv_classes = __all__[3:8]
+pool_classes = __all__[8:]
