@@ -8,8 +8,7 @@ from torch_geometric.typing import OptTensor
 
 
 class DenseGCNConv(torch.nn.Module):
-    r"""See :class:`torch_geometric.nn.conv.GCNConv`.
-    """
+    r"""See :class:`torch_geometric.nn.conv.GCNConv`."""
     def __init__(
         self,
         in_channels: int,
@@ -34,6 +33,7 @@ class DenseGCNConv(torch.nn.Module):
         self.reset_parameters()
 
     def reset_parameters(self):
+        r"""Resets all learnable parameters of the module."""
         self.lin.reset_parameters()
         zeros(self.bias)
 
@@ -41,15 +41,15 @@ class DenseGCNConv(torch.nn.Module):
                 add_loop: bool = True) -> Tensor:
         r"""
         Args:
-            x (Tensor): Node feature tensor :math:`\mathbf{X} \in \mathbb{R}^{B
-                \times N \times F}`, with batch-size :math:`B`, (maximum)
-                number of nodes :math:`N` for each graph, and feature
-                dimension :math:`F`.
-            adj (Tensor): Adjacency tensor :math:`\mathbf{A} \in \mathbb{R}^{B
-                \times N \times N}`. The adjacency tensor is broadcastable in
-                the batch dimension, resulting in a shared adjacency matrix for
-                the complete batch.
-            mask (BoolTensor, optional): Mask matrix
+            x (torch.Tensor): Node feature tensor
+                :math:`\mathbf{X} \in \mathbb{R}^{B \times N \times F}`, with
+                batch-size :math:`B`, (maximum) number of nodes :math:`N` for
+                each graph, and feature dimension :math:`F`.
+            adj (torch.Tensor): Adjacency tensor
+                :math:`\mathbf{A} \in \mathbb{R}^{B \times N \times N}`.
+                The adjacency tensor is broadcastable in the batch dimension,
+                resulting in a shared adjacency matrix for the complete batch.
+            mask (torch.Tensor, optional): Mask matrix
                 :math:`\mathbf{M} \in {\{ 0, 1 \}}^{B \times N}` indicating
                 the valid nodes for each graph. (default: :obj:`None`)
             add_loop (bool, optional): If set to :obj:`False`, the layer will
