@@ -2,23 +2,22 @@ import os
 import os.path as osp
 from math import pi as PI
 from math import sqrt
-from typing import Callable, Optional, Tuple, Union
+from typing import Callable, Dict, Optional, Tuple, Union
 
 import numpy as np
 import torch
 from torch import Tensor
 from torch.nn import Embedding, Linear
-from torch_scatter import scatter
-from torch_sparse import SparseTensor
 
 from torch_geometric.data import Dataset, download_url
 from torch_geometric.data.makedirs import makedirs
 from torch_geometric.nn import radius_graph
 from torch_geometric.nn.inits import glorot_orthogonal
 from torch_geometric.nn.resolver import activation_resolver
-from torch_geometric.typing import OptTensor
+from torch_geometric.typing import OptTensor, SparseTensor
+from torch_geometric.utils import scatter
 
-qm9_target_dict = {
+qm9_target_dict: Dict[int, str] = {
     0: 'mu',
     1: 'alpha',
     2: 'homo',
@@ -46,7 +45,7 @@ class Envelope(torch.nn.Module):
         x_pow_p0 = x.pow(p - 1)
         x_pow_p1 = x_pow_p0 * x
         x_pow_p2 = x_pow_p1 * x
-        return (1. / x + a * x_pow_p0 + b * x_pow_p1 +
+        return (1.0 / x + a * x_pow_p0 + b * x_pow_p1 +
                 c * x_pow_p2) * (x < 1.0).to(x.dtype)
 
 
@@ -67,13 +66,18 @@ class BesselBasisLayer(torch.nn.Module):
         self.freq.requires_grad_()
 
     def forward(self, dist: Tensor) -> Tensor:
-        dist = (dist.unsqueeze(-1) / self.cutoff)
+        dist = dist.unsqueeze(-1) / self.cutoff
         return self.envelope(dist) * (self.freq * dist).sin()
 
 
 class SphericalBasisLayer(torch.nn.Module):
-    def __init__(self, num_spherical: int, num_radial: int,
-                 cutoff: float = 5.0, envelope_exponent: int = 5):
+    def __init__(
+        self,
+        num_spherical: int,
+        num_radial: int,
+        cutoff: float = 5.0,
+        envelope_exponent: int = 5,
+    ):
         super().__init__()
         import sympy as sym
 
@@ -160,9 +164,16 @@ class ResidualLayer(torch.nn.Module):
 
 
 class InteractionBlock(torch.nn.Module):
-    def __init__(self, hidden_channels: int, num_bilinear: int,
-                 num_spherical: int, num_radial: int, num_before_skip: int,
-                 num_after_skip: int, act: Callable):
+    def __init__(
+        self,
+        hidden_channels: int,
+        num_bilinear: int,
+        num_spherical: int,
+        num_radial: int,
+        num_before_skip: int,
+        num_after_skip: int,
+        act: Callable,
+    ):
         super().__init__()
         self.act = act
 
@@ -211,7 +222,7 @@ class InteractionBlock(torch.nn.Module):
         x_kj = self.act(self.lin_kj(x))
         x_kj = x_kj * rbf
         x_kj = torch.einsum('wj,wl,ijl->wi', sbf, x_kj[idx_kj], self.W)
-        x_kj = scatter(x_kj, idx_ji, dim=0, dim_size=x.size(0))
+        x_kj = scatter(x_kj, idx_ji, dim=0, dim_size=x.size(0), reduce='sum')
 
         h = x_ji + x_kj
         for layer in self.layers_before_skip:
@@ -224,9 +235,17 @@ class InteractionBlock(torch.nn.Module):
 
 
 class InteractionPPBlock(torch.nn.Module):
-    def __init__(self, hidden_channels: int, int_emb_size: int,
-                 basis_emb_size: int, num_spherical: int, num_radial: int,
-                 num_before_skip: int, num_after_skip: int, act: Callable):
+    def __init__(
+        self,
+        hidden_channels: int,
+        int_emb_size: int,
+        basis_emb_size: int,
+        num_spherical: int,
+        num_radial: int,
+        num_before_skip: int,
+        num_after_skip: int,
+        act: Callable,
+    ):
         super().__init__()
         self.act = act
 
@@ -275,7 +294,7 @@ class InteractionPPBlock(torch.nn.Module):
             res_layer.reset_parameters()
         glorot_orthogonal(self.lin.weight, scale=2.0)
         self.lin.bias.data.fill_(0)
-        for res_layer in self.layers_before_skip:
+        for res_layer in self.layers_after_skip:
             res_layer.reset_parameters()
 
     def forward(self, x: Tensor, rbf: Tensor, sbf: Tensor, idx_kj: Tensor,
@@ -298,7 +317,7 @@ class InteractionPPBlock(torch.nn.Module):
         x_kj = x_kj[idx_kj] * sbf
 
         # Aggregate interactions and up-project embeddings:
-        x_kj = scatter(x_kj, idx_ji, dim=0, dim_size=x.size(0))
+        x_kj = scatter(x_kj, idx_ji, dim=0, dim_size=x.size(0), reduce='sum')
         x_kj = self.act(self.lin_up(x_kj))
 
         h = x_ji + x_kj
@@ -312,8 +331,14 @@ class InteractionPPBlock(torch.nn.Module):
 
 
 class OutputBlock(torch.nn.Module):
-    def __init__(self, num_radial: int, hidden_channels: int,
-                 out_channels: int, num_layers: int, act: Callable):
+    def __init__(
+        self,
+        num_radial: int,
+        hidden_channels: int,
+        out_channels: int,
+        num_layers: int,
+        act: Callable,
+    ):
         super().__init__()
         self.act = act
 
@@ -335,16 +360,22 @@ class OutputBlock(torch.nn.Module):
     def forward(self, x: Tensor, rbf: Tensor, i: Tensor,
                 num_nodes: Optional[int] = None) -> Tensor:
         x = self.lin_rbf(rbf) * x
-        x = scatter(x, i, dim=0, dim_size=num_nodes)
+        x = scatter(x, i, dim=0, dim_size=num_nodes, reduce='sum')
         for lin in self.lins:
             x = self.act(lin(x))
         return self.lin(x)
 
 
 class OutputPPBlock(torch.nn.Module):
-    def __init__(self, num_radial: int, hidden_channels: int,
-                 out_emb_channels: int, out_channels: int, num_layers: int,
-                 act: Callable):
+    def __init__(
+        self,
+        num_radial: int,
+        hidden_channels: int,
+        out_emb_channels: int,
+        out_channels: int,
+        num_layers: int,
+        act: Callable,
+    ):
         super().__init__()
         self.act = act
 
@@ -370,13 +401,39 @@ class OutputPPBlock(torch.nn.Module):
     def forward(self, x: Tensor, rbf: Tensor, i: Tensor,
                 num_nodes: Optional[int] = None) -> Tensor:
         x = self.lin_rbf(rbf) * x
-        x = scatter(x, i, dim=0, dim_size=num_nodes)
+        x = scatter(x, i, dim=0, dim_size=num_nodes, reduce='sum')
         x = self.lin_up(x)
         for lin in self.lins:
             x = self.act(lin(x))
         return self.lin(x)
 
 
+def triplets(
+    edge_index: Tensor,
+    num_nodes: int,
+) -> Tuple[Tensor, Tensor, Tensor, Tensor, Tensor, Tensor, Tensor]:
+    row, col = edge_index  # j->i
+
+    value = torch.arange(row.size(0), device=row.device)
+    adj_t = SparseTensor(row=col, col=row, value=value,
+                         sparse_sizes=(num_nodes, num_nodes))
+    adj_t_row = adj_t[row]
+    num_triplets = adj_t_row.set_value(None).sum(dim=1).to(torch.long)
+
+    # Node indices (k->j->i) for triplets.
+    idx_i = col.repeat_interleave(num_triplets)
+    idx_j = row.repeat_interleave(num_triplets)
+    idx_k = adj_t_row.storage.col()
+    mask = idx_i != idx_k  # Remove i == k triplets.
+    idx_i, idx_j, idx_k = idx_i[mask], idx_j[mask], idx_k[mask]
+
+    # Edge indices (k-j, j->i) for triplets.
+    idx_kj = adj_t_row.storage.value()[mask]
+    idx_ji = adj_t_row.storage.row()[mask]
+
+    return col, row, idx_i, idx_j, idx_k, idx_kj, idx_ji
+
+
 class DimeNet(torch.nn.Module):
     r"""The directional message passing neural network (DimeNet) from the
     `"Directional Message Passing for Molecular Graphs"
@@ -425,7 +482,7 @@ class DimeNet(torch.nn.Module):
         num_blocks: int,
         num_bilinear: int,
         num_spherical: int,
-        num_radial,
+        num_radial: int,
         cutoff: float = 5.0,
         max_num_neighbors: int = 32,
         envelope_exponent: int = 5,
@@ -437,7 +494,7 @@ class DimeNet(torch.nn.Module):
         super().__init__()
 
         if num_spherical < 2:
-            raise ValueError("num_spherical should be greater than 1")
+            raise ValueError("'num_spherical' should be greater than 1")
 
         act = activation_resolver(act)
 
@@ -457,14 +514,19 @@ class DimeNet(torch.nn.Module):
         ])
 
         self.interaction_blocks = torch.nn.ModuleList([
-            InteractionBlock(hidden_channels, num_bilinear, num_spherical,
-                             num_radial, num_before_skip, num_after_skip, act)
-            for _ in range(num_blocks)
+            InteractionBlock(
+                hidden_channels,
+                num_bilinear,
+                num_spherical,
+                num_radial,
+                num_before_skip,
+                num_after_skip,
+                act,
+            ) for _ in range(num_blocks)
         ])
 
-        self.reset_parameters()
-
     def reset_parameters(self):
+        r"""Resets all learnable parameters of the module."""
         self.rbf.reset_parameters()
         self.emb.reset_parameters()
         for out in self.output_blocks:
@@ -478,7 +540,10 @@ class DimeNet(torch.nn.Module):
         root: str,
         dataset: Dataset,
         target: int,
-    ) -> Tuple['DimeNet', Dataset, Dataset, Dataset]:
+    ) -> Tuple['DimeNet', Dataset, Dataset, Dataset]:  # pragma: no cover
+        r"""Returns a pre-trained :class:`DimeNet` model on the
+        :class:`~torch_geometric.datasets.QM9` dataset, trained on the
+        specified target :obj:`target`."""
         os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
         import tensorflow as tf
 
@@ -572,43 +637,26 @@ class DimeNet(torch.nn.Module):
 
         return model, (dataset[train_idx], dataset[val_idx], dataset[test_idx])
 
-    def triplets(
-        self,
-        edge_index: Tensor,
-        num_nodes: int,
-    ) -> Tuple[Tensor, Tensor, Tensor, Tensor, Tensor, Tensor, Tensor]:
-        row, col = edge_index  # j->i
-
-        value = torch.arange(row.size(0), device=row.device)
-        adj_t = SparseTensor(row=col, col=row, value=value,
-                             sparse_sizes=(num_nodes, num_nodes))
-        adj_t_row = adj_t[row]
-        num_triplets = adj_t_row.set_value(None).sum(dim=1).to(torch.long)
-
-        # Node indices (k->j->i) for triplets.
-        idx_i = col.repeat_interleave(num_triplets)
-        idx_j = row.repeat_interleave(num_triplets)
-        idx_k = adj_t_row.storage.col()
-        mask = idx_i != idx_k  # Remove i == k triplets.
-        idx_i, idx_j, idx_k = idx_i[mask], idx_j[mask], idx_k[mask]
-
-        # Edge indices (k-j, j->i) for triplets.
-        idx_kj = adj_t_row.storage.value()[mask]
-        idx_ji = adj_t_row.storage.row()[mask]
-
-        return col, row, idx_i, idx_j, idx_k, idx_kj, idx_ji
-
     def forward(
         self,
         z: Tensor,
         pos: Tensor,
         batch: OptTensor = None,
     ) -> Tensor:
-        """"""
+        r"""
+        Args:
+            z (torch.Tensor): Atomic number of each atom with shape
+                :obj:`[num_atoms]`.
+            pos (torch.Tensor): Coordinates of each atom with shape
+                :obj:`[num_atoms, 3]`.
+            batch (torch.Tensor, optional): Batch indices assigning each atom
+                to a separate molecule with shape :obj:`[num_atoms]`.
+                (default: :obj:`None`)
+        """
         edge_index = radius_graph(pos, r=self.cutoff, batch=batch,
                                   max_num_neighbors=self.max_num_neighbors)
 
-        i, j, idx_i, idx_j, idx_k, idx_kj, idx_ji = self.triplets(
+        i, j, idx_i, idx_j, idx_k, idx_kj, idx_ji = triplets(
             edge_index, num_nodes=z.size(0))
 
         # Calculate distances.
@@ -632,9 +680,12 @@ class DimeNet(torch.nn.Module):
         for interaction_block, output_block in zip(self.interaction_blocks,
                                                    self.output_blocks[1:]):
             x = interaction_block(x, rbf, sbf, idx_kj, idx_ji)
-            P = P + output_block(x, rbf, i)
+            P = P + output_block(x, rbf, i, num_nodes=pos.size(0))
 
-        return P.sum(dim=0) if batch is None else scatter(P, batch, dim=0)
+        if batch is None:
+            return P.sum(dim=0)
+        else:
+            return scatter(P, batch, dim=0, reduce='sum')
 
 
 class DimeNetPlusPlus(DimeNet):
@@ -716,15 +767,27 @@ class DimeNetPlusPlus(DimeNet):
         # variable `num_bilinear` does not have any purpose as it is used
         # solely in the `OutputBlock` of DimeNet:
         self.output_blocks = torch.nn.ModuleList([
-            OutputPPBlock(num_radial, hidden_channels, out_emb_channels,
-                          out_channels, num_output_layers, act)
-            for _ in range(num_blocks + 1)
+            OutputPPBlock(
+                num_radial,
+                hidden_channels,
+                out_emb_channels,
+                out_channels,
+                num_output_layers,
+                act,
+            ) for _ in range(num_blocks + 1)
         ])
 
         self.interaction_blocks = torch.nn.ModuleList([
-            InteractionPPBlock(hidden_channels, int_emb_size, basis_emb_size,
-                               num_spherical, num_radial, num_before_skip,
-                               num_after_skip, act) for _ in range(num_blocks)
+            InteractionPPBlock(
+                hidden_channels,
+                int_emb_size,
+                basis_emb_size,
+                num_spherical,
+                num_radial,
+                num_before_skip,
+                num_after_skip,
+                act,
+            ) for _ in range(num_blocks)
         ])
 
         self.reset_parameters()
@@ -735,7 +798,11 @@ class DimeNetPlusPlus(DimeNet):
         root: str,
         dataset: Dataset,
         target: int,
-    ) -> Tuple['DimeNetPlusPlus', Dataset, Dataset, Dataset]:
+    ) -> Tuple['DimeNetPlusPlus', Dataset, Dataset,
+               Dataset]:  # pragma: no cover
+        r"""Returns a pre-trained :class:`DimeNetPlusPlus` model on the
+        :class:`~torch_geometric.datasets.QM9` dataset, trained on the
+        specified target :obj:`target`."""
         os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
         import tensorflow as tf
 
