@@ -1,4 +1,4 @@
-from typing import Iterable, Mapping, Optional
+from typing import Iterable, Mapping, Optional, Tuple
 
 import torch
 from torch.nn import Module
@@ -10,8 +10,7 @@ from torch.nn import Module
 # representation.
 class ModuleDict(torch.nn.ModuleDict):
     def __init__(self, modules: Optional[Mapping[str, Module]] = None):
-        # Replace the keys in modules.
-        if modules:
+        if modules is not None:  # Replace the keys in modules:
             modules = {
                 self.to_internal_key(key): module
                 for key, module in modules.items()
@@ -29,10 +28,10 @@ class ModuleDict(torch.nn.ModuleDict):
     def __getitem__(self, key: str) -> Module:
         return super().__getitem__(self.to_internal_key(key))
 
-    def __setitem__(self, key: str, module: Module) -> None:
+    def __setitem__(self, key: str, module: Module):
         return super().__setitem__(self.to_internal_key(key), module)
 
-    def __delitem__(self, key: str) -> None:
+    def __delitem__(self, key: str):
         return super().__delitem__(self.to_internal_key(key))
 
     def __contains__(self, key: str) -> bool:
@@ -40,3 +39,7 @@ class ModuleDict(torch.nn.ModuleDict):
 
     def keys(self) -> Iterable[str]:
         return [self.to_external_key(key) for key in super().keys()]
+
+    def items(self) -> Iterable[Tuple[str, Module]]:
+        return [(self.to_external_key(key), value)
+                for key, value in super().items()]
