@@ -1,13 +1,18 @@
-from .max_pool import max_pool, max_pool_x, max_pool_neighbor_x
-from .avg_pool import avg_pool, avg_pool_x, avg_pool_neighbor_x
-from .graclus import graclus
-from .voxel_grid import voxel_grid
-from .topk_pool import TopKPooling
-from .sag_pool import SAGPooling
-from .edge_pool import EdgePooling
+from torch import Tensor
+
+from torch_geometric.typing import OptTensor
+
 from .asap import ASAPooling
-from .pan_pool import PANPooling
+from .avg_pool import avg_pool, avg_pool_neighbor_x, avg_pool_x
+from .edge_pool import EdgePooling
+from .glob import global_add_pool, global_max_pool, global_mean_pool
+from .graclus import graclus
+from .max_pool import max_pool, max_pool_neighbor_x, max_pool_x
 from .mem_pool import MemPooling
+from .pan_pool import PANPooling
+from .sag_pool import SAGPooling
+from .topk_pool import TopKPooling
+from .voxel_grid import voxel_grid
 
 try:
     import torch_cluster
@@ -15,24 +20,13 @@ except ImportError:
     torch_cluster = None
 
 
-def fps(x, batch=None, ratio=0.5, random_start=True):
+def fps(x: Tensor, batch: OptTensor = None, ratio: float = 0.5,
+        random_start: bool = True) -> Tensor:
     r"""A sampling algorithm from the `"PointNet++: Deep Hierarchical Feature
     Learning on Point Sets in a Metric Space"
     <https://arxiv.org/abs/1706.02413>`_ paper, which iteratively samples the
     most distant point with regard to the rest points.
 
-    Args:
-        x (Tensor): Node feature matrix
-            :math:`\mathbf{X} \in \mathbb{R}^{N \times F}`.
-        batch (LongTensor, optional): Batch vector
-            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^N`, which assigns each
-            node to a specific example. (default: :obj:`None`)
-        ratio (float, optional): Sampling ratio. (default: :obj:`0.5`)
-        random_start (bool, optional): If set to :obj:`False`, use the first
-            node in :math:`\mathbf{X}` as starting node. (default: obj:`True`)
-
-    :rtype: :class:`LongTensor`
-
     .. code-block:: python
 
         import torch
@@ -41,38 +35,28 @@ def fps(x, batch=None, ratio=0.5, random_start=True):
         x = torch.Tensor([[-1, -1], [-1, 1], [1, -1], [1, 1]])
         batch = torch.tensor([0, 0, 0, 0])
         index = fps(x, batch, ratio=0.5)
-    """
-    if torch_cluster is None:
-        raise ImportError('`fps` requires `torch-cluster`.')
 
+    Args:
+        x (torch.Tensor): Node feature matrix
+            :math:`\mathbf{X} \in \mathbb{R}^{N \times F}`.
+        batch (torch.Tensor, optional): Batch vector
+            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^N`, which assigns each
+            node to a specific example. (default: :obj:`None`)
+        ratio (float, optional): Sampling ratio. (default: :obj:`0.5`)
+        random_start (bool, optional): If set to :obj:`False`, use the first
+            node in :math:`\mathbf{X}` as starting node. (default: obj:`True`)
+
+    :rtype: :class:`torch.Tensor`
+    """
     return torch_cluster.fps(x, batch, ratio, random_start)
 
 
-def knn(x, y, k, batch_x=None, batch_y=None, cosine=False, num_workers=1):
+def knn(x: Tensor, y: Tensor, k: int, batch_x: OptTensor = None,
+        batch_y: OptTensor = None, cosine: bool = False,
+        num_workers: int = 1) -> Tensor:
     r"""Finds for each element in :obj:`y` the :obj:`k` nearest points in
     :obj:`x`.
 
-    Args:
-        x (Tensor): Node feature matrix
-            :math:`\mathbf{X} \in \mathbb{R}^{N \times F}`.
-        y (Tensor): Node feature matrix
-            :math:`\mathbf{X} \in \mathbb{R}^{M \times F}`.
-        k (int): The number of neighbors.
-        batch_x (LongTensor, optional): Batch vector
-            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^N`, which assigns each
-            node to a specific example. (default: :obj:`None`)
-        batch_y (LongTensor, optional): Batch vector
-            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^M`, which assigns each
-            node to a specific example. (default: :obj:`None`)
-        cosine (boolean, optional): If :obj:`True`, will use the cosine
-            distance instead of euclidean distance to find nearest neighbors.
-            (default: :obj:`False`)
-        num_workers (int): Number of workers to use for computation. Has no
-            effect in case :obj:`batch_x` or :obj:`batch_y` is not
-            :obj:`None`, or the input lies on the GPU. (default: :obj:`1`)
-
-    :rtype: :class:`LongTensor`
-
     .. code-block:: python
 
         import torch
@@ -83,38 +67,36 @@ def knn(x, y, k, batch_x=None, batch_y=None, cosine=False, num_workers=1):
         y = torch.Tensor([[-1, 0], [1, 0]])
         batch_y = torch.tensor([0, 0])
         assign_index = knn(x, y, 2, batch_x, batch_y)
-    """
-    if torch_cluster is None:
-        raise ImportError('`knn` requires `torch-cluster`.')
 
+    Args:
+        x (torch.Tensor): Node feature matrix
+            :math:`\mathbf{X} \in \mathbb{R}^{N \times F}`.
+        y (torch.Tensor): Node feature matrix
+            :math:`\mathbf{X} \in \mathbb{R}^{M \times F}`.
+        k (int): The number of neighbors.
+        batch_x (torch.Tensor, optional): Batch vector
+            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^N`, which assigns each
+            node to a specific example. (default: :obj:`None`)
+        batch_y (torch.Tensor, optional): Batch vector
+            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^M`, which assigns each
+            node to a specific example. (default: :obj:`None`)
+        cosine (bool, optional): If :obj:`True`, will use the cosine
+            distance instead of euclidean distance to find nearest neighbors.
+            (default: :obj:`False`)
+        num_workers (int, optional): Number of workers to use for computation.
+            Has no effect in case :obj:`batch_x` or :obj:`batch_y` is not
+            :obj:`None`, or the input lies on the GPU. (default: :obj:`1`)
+
+    :rtype: :class:`torch.Tensor`
+    """
     return torch_cluster.knn(x, y, k, batch_x, batch_y, cosine, num_workers)
 
 
-def knn_graph(x, k, batch=None, loop=False, flow='source_to_target',
-              cosine=False, num_workers=1):
+def knn_graph(x: Tensor, k: int, batch: OptTensor = None, loop: bool = False,
+              flow: str = 'source_to_target', cosine: bool = False,
+              num_workers: int = 1) -> Tensor:
     r"""Computes graph edges to the nearest :obj:`k` points.
 
-    Args:
-        x (Tensor): Node feature matrix
-            :math:`\mathbf{X} \in \mathbb{R}^{N \times F}`.
-        k (int): The number of neighbors.
-        batch (LongTensor, optional): Batch vector
-            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^N`, which assigns each
-            node to a specific example. (default: :obj:`None`)
-        loop (bool, optional): If :obj:`True`, the graph will contain
-            self-loops. (default: :obj:`False`)
-        flow (string, optional): The flow direction when using in combination
-            with message passing (:obj:`"source_to_target"` or
-            :obj:`"target_to_source"`). (default: :obj:`"source_to_target"`)
-        cosine (boolean, optional): If :obj:`True`, will use the cosine
-            distance instead of euclidean distance to find nearest neighbors.
-            (default: :obj:`False`)
-        num_workers (int): Number of workers to use for computation. Has no
-            effect in case :obj:`batch` is not :obj:`None`, or the input lies
-            on the GPU. (default: :obj:`1`)
-
-    :rtype: :class:`LongTensor`
-
     .. code-block:: python
 
         import torch
@@ -123,39 +105,38 @@ def knn_graph(x, k, batch=None, loop=False, flow='source_to_target',
         x = torch.Tensor([[-1, -1], [-1, 1], [1, -1], [1, 1]])
         batch = torch.tensor([0, 0, 0, 0])
         edge_index = knn_graph(x, k=2, batch=batch, loop=False)
-    """
-    if torch_cluster is None:
-        raise ImportError('`knn_graph` requires `torch-cluster`.')
 
+    Args:
+        x (torch.Tensor): Node feature matrix
+            :math:`\mathbf{X} \in \mathbb{R}^{N \times F}`.
+        k (int): The number of neighbors.
+        batch (torch.Tensor, optional): Batch vector
+            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^N`, which assigns each
+            node to a specific example. (default: :obj:`None`)
+        loop (bool, optional): If :obj:`True`, the graph will contain
+            self-loops. (default: :obj:`False`)
+        flow (str, optional): The flow direction when using in combination with
+            message passing (:obj:`"source_to_target"` or
+            :obj:`"target_to_source"`). (default: :obj:`"source_to_target"`)
+        cosine (bool, optional): If :obj:`True`, will use the cosine
+            distance instead of euclidean distance to find nearest neighbors.
+            (default: :obj:`False`)
+        num_workers (int, optional): Number of workers to use for computation.
+            Has no effect in case :obj:`batch` is not :obj:`None`, or the input
+            lies on the GPU. (default: :obj:`1`)
+
+    :rtype: :class:`torch.Tensor`
+    """
     return torch_cluster.knn_graph(x, k, batch, loop, flow, cosine,
                                    num_workers)
 
 
-def radius(x, y, r, batch_x=None, batch_y=None, max_num_neighbors=32,
-           num_workers=1):
+def radius(x: Tensor, y: Tensor, r: float, batch_x: OptTensor = None,
+           batch_y: OptTensor = None, max_num_neighbors: int = 32,
+           num_workers: int = 1) -> Tensor:
     r"""Finds for each element in :obj:`y` all points in :obj:`x` within
     distance :obj:`r`.
 
-    Args:
-        x (Tensor): Node feature matrix
-            :math:`\mathbf{X} \in \mathbb{R}^{N \times F}`.
-        y (Tensor): Node feature matrix
-            :math:`\mathbf{Y} \in \mathbb{R}^{M \times F}`.
-        r (float): The radius.
-        batch_x (LongTensor, optional): Batch vector
-            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^N`, which assigns each
-            node to a specific example. (default: :obj:`None`)
-        batch_y (LongTensor, optional): Batch vector
-            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^M`, which assigns each
-            node to a specific example. (default: :obj:`None`)
-        max_num_neighbors (int, optional): The maximum number of neighbors to
-            return for each element in :obj:`y`. (default: :obj:`32`)
-        num_workers (int): Number of workers to use for computation. Has no
-            effect in case :obj:`batch_x` or :obj:`batch_y` is not
-            :obj:`None`, or the input lies on the GPU. (default: :obj:`1`)
-
-    :rtype: :class:`LongTensor`
-
     .. code-block:: python
 
         import torch
@@ -166,38 +147,37 @@ def radius(x, y, r, batch_x=None, batch_y=None, max_num_neighbors=32,
         y = torch.Tensor([[-1, 0], [1, 0]])
         batch_y = torch.tensor([0, 0])
         assign_index = radius(x, y, 1.5, batch_x, batch_y)
-    """
-    if torch_cluster is None:
-        raise ImportError('`radius` requires `torch-cluster`.')
 
+    Args:
+        x (torch.Tensor): Node feature matrix
+            :math:`\mathbf{X} \in \mathbb{R}^{N \times F}`.
+        y (torch.Tensor): Node feature matrix
+            :math:`\mathbf{Y} \in \mathbb{R}^{M \times F}`.
+        r (float): The radius.
+        batch_x (torch.Tensor, optional): Batch vector
+            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^N`, which assigns each
+            node to a specific example. (default: :obj:`None`)
+        batch_y (torch.Tensor, optional): Batch vector
+            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^M`, which assigns each
+            node to a specific example. (default: :obj:`None`)
+        max_num_neighbors (int, optional): The maximum number of neighbors to
+            return for each element in :obj:`y`. (default: :obj:`32`)
+        num_workers (int, optional): Number of workers to use for computation.
+            Has no effect in case :obj:`batch_x` or :obj:`batch_y` is not
+            :obj:`None`, or the input lies on the GPU. (default: :obj:`1`)
+
+    :rtype: :class:`torch.Tensor`
+    """
     return torch_cluster.radius(x, y, r, batch_x, batch_y, max_num_neighbors,
                                 num_workers)
 
 
-def radius_graph(x, r, batch=None, loop=False, max_num_neighbors=32,
-                 flow='source_to_target', num_workers=1):
+def radius_graph(x: Tensor, r: float, batch: OptTensor = None,
+                 loop: bool = False, max_num_neighbors: int = 32,
+                 flow: str = 'source_to_target',
+                 num_workers: int = 1) -> Tensor:
     r"""Computes graph edges to all points within a given distance.
 
-    Args:
-        x (Tensor): Node feature matrix
-            :math:`\mathbf{X} \in \mathbb{R}^{N \times F}`.
-        r (float): The radius.
-        batch (LongTensor, optional): Batch vector
-            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^N`, which assigns each
-            node to a specific example. (default: :obj:`None`)
-        loop (bool, optional): If :obj:`True`, the graph will contain
-            self-loops. (default: :obj:`False`)
-        max_num_neighbors (int, optional): The maximum number of neighbors to
-            return for each element in :obj:`y`. (default: :obj:`32`)
-        flow (string, optional): The flow direction when using in combination
-            with message passing (:obj:`"source_to_target"` or
-            :obj:`"target_to_source"`). (default: :obj:`"source_to_target"`)
-        num_workers (int): Number of workers to use for computation. Has no
-            effect in case :obj:`batch` is not :obj:`None`, or the input lies
-            on the GPU. (default: :obj:`1`)
-
-    :rtype: :class:`LongTensor`
-
     .. code-block:: python
 
         import torch
@@ -206,31 +186,35 @@ def radius_graph(x, r, batch=None, loop=False, max_num_neighbors=32,
         x = torch.Tensor([[-1, -1], [-1, 1], [1, -1], [1, 1]])
         batch = torch.tensor([0, 0, 0, 0])
         edge_index = radius_graph(x, r=1.5, batch=batch, loop=False)
-    """
-    if torch_cluster is None:
-        raise ImportError('`radius_graph` requires `torch-cluster`.')
 
+    Args:
+        x (torch.Tensor): Node feature matrix
+            :math:`\mathbf{X} \in \mathbb{R}^{N \times F}`.
+        r (float): The radius.
+        batch (torch.Tensor, optional): Batch vector
+            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^N`, which assigns each
+            node to a specific example. (default: :obj:`None`)
+        loop (bool, optional): If :obj:`True`, the graph will contain
+            self-loops. (default: :obj:`False`)
+        max_num_neighbors (int, optional): The maximum number of neighbors to
+            return for each element in :obj:`y`. (default: :obj:`32`)
+        flow (str, optional): The flow direction when using in combination with
+            message passing (:obj:`"source_to_target"` or
+            :obj:`"target_to_source"`). (default: :obj:`"source_to_target"`)
+        num_workers (int, optional): Number of workers to use for computation.
+            Has no effect in case :obj:`batch` is not :obj:`None`, or the input
+            lies on the GPU. (default: :obj:`1`)
+
+    :rtype: :class:`torch.Tensor`
+    """
     return torch_cluster.radius_graph(x, r, batch, loop, max_num_neighbors,
                                       flow, num_workers)
 
 
-def nearest(x, y, batch_x=None, batch_y=None):
-    r"""Clusters points in :obj:`x` together which are nearest to a given query
-    point in :obj:`y`.
-
-    Args:
-        x (Tensor): Node feature matrix
-            :math:`\mathbf{X} \in \mathbb{R}^{N \times F}`.
-        y (Tensor): Node feature matrix
-            :math:`\mathbf{Y} \in \mathbb{R}^{M \times F}`.
-        batch_x (LongTensor, optional): Batch vector
-            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^N`, which assigns each
-            node to a specific example. (default: :obj:`None`)
-        batch_y (LongTensor, optional): Batch vector
-            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^M`, which assigns each
-            node to a specific example. (default: :obj:`None`)
-
-    :rtype: :class:`LongTensor`
+def nearest(x: Tensor, y: Tensor, batch_x: OptTensor = None,
+            batch_y: OptTensor = None) -> Tensor:
+    r"""Finds for each element in :obj:`y` the :obj:`k` nearest point in
+    :obj:`x`.
 
     .. code-block:: python
 
@@ -242,14 +226,28 @@ def nearest(x, y, batch_x=None, batch_y=None):
         y = torch.Tensor([[-1, 0], [1, 0]])
         batch_y = torch.tensor([0, 0])
         cluster = nearest(x, y, batch_x, batch_y)
-    """
-    if torch_cluster is None:
-        raise ImportError('`radius` requires `torch-cluster`.')
 
+    Args:
+        x (torch.Tensor): Node feature matrix
+            :math:`\mathbf{X} \in \mathbb{R}^{N \times F}`.
+        y (torch.Tensor): Node feature matrix
+            :math:`\mathbf{Y} \in \mathbb{R}^{M \times F}`.
+        batch_x (torch.Tensor, optional): Batch vector
+            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^N`, which assigns each
+            node to a specific example. (default: :obj:`None`)
+        batch_y (torch.Tensor, optional): Batch vector
+            :math:`\mathbf{b} \in {\{ 0, \ldots, B-1\}}^M`, which assigns each
+            node to a specific example. (default: :obj:`None`)
+
+    :rtype: :class:`torch.Tensor`
+    """
     return torch_cluster.nearest(x, y, batch_x, batch_y)
 
 
 __all__ = [
+    'global_add_pool',
+    'global_mean_pool',
+    'global_max_pool',
     'TopKPooling',
     'SAGPooling',
     'EdgePooling',
