@@ -6,6 +6,7 @@ from typing import Any, Dict, Optional, Tuple, Union
 import torch
 from torch.nn import Module
 
+from torch_geometric.nn.dense.linear import is_uninitialized_parameter
 from torch_geometric.nn.fx import Transformer, get_submodule
 from torch_geometric.typing import EdgeType, Metadata, NodeType
 from torch_geometric.utils.hetero import (
@@ -100,8 +101,8 @@ def to_hetero(module: Module, metadata: Metadata, aggr: str = "sum",
             by a list of strings and a list of string triplets, respectively.
             See :meth:`torch_geometric.data.HeteroData.metadata` for more
             information.
-        aggr (string, optional): The aggregation scheme to use for grouping
-            node embeddings generated by different relations.
+        aggr (str, optional): The aggregation scheme to use for grouping node
+            embeddings generated by different relations
             (:obj:`"sum"`, :obj:`"mean"`, :obj:`"min"`, :obj:`"max"`,
             :obj:`"mul"`). (default: :obj:`"sum"`)
         input_map (Dict[str, str], optional): A dictionary holding information
@@ -156,14 +157,14 @@ class ToHeteroTransformer(Transformer):
                 f"There exist node types ({unused_node_types}) whose "
                 f"representations do not get updated during message passing "
                 f"as they do not occur as destination type in any edge type. "
-                f"This may lead to unexpected behaviour.")
+                f"This may lead to unexpected behavior.")
 
         names = self.metadata[0] + [rel for _, rel, _ in self.metadata[1]]
         for name in names:
             if not name.isidentifier():
                 warnings.warn(
                     f"The type '{name}' contains invalid characters which "
-                    f"may lead to unexpected behaviour. To avoid any issues, "
+                    f"may lead to unexpected behavior. To avoid any issues, "
                     f"ensure that your types only contain letters, numbers "
                     f"and underscores.")
 
@@ -371,7 +372,10 @@ class ToHeteroTransformer(Transformer):
                 continue
             if hasattr(module, 'reset_parameters'):
                 module_dict[key2str(key)].reset_parameters()
-            elif sum([p.numel() for p in module.parameters()]) > 0:
+            elif sum([
+                    is_uninitialized_parameter(p) or p.numel()
+                    for p in module.parameters()
+            ]) > 0:
                 warnings.warn(
                     f"'{target}' will be duplicated, but its parameters "
                     f"cannot be reset. To suppress this warning, add a "
