@@ -7,7 +7,7 @@ from torch_geometric.transforms import BaseTransform
 
 @functional_transform('center')
 class Center(BaseTransform):
-    r"""Centers node positions :obj:`pos` around the origin
+    r"""Centers node positions :obj:`data.pos` around the origin
     (functional name: :obj:`center`)."""
     def __call__(
         self,
