@@ -1,5 +1,6 @@
-from typing import List, Callable
+from typing import Callable, List, Union
 
+from torch_geometric.data import Data, HeteroData
 from torch_geometric.transforms import BaseTransform
 
 
@@ -12,7 +13,10 @@ class Compose(BaseTransform):
     def __init__(self, transforms: List[Callable]):
         self.transforms = transforms
 
-    def __call__(self, data):
+    def __call__(
+        self,
+        data: Union[Data, HeteroData],
+    ) -> Union[Data, HeteroData]:
         for transform in self.transforms:
             if isinstance(data, (list, tuple)):
                 data = [transform(d) for d in data]
@@ -20,6 +24,6 @@ class Compose(BaseTransform):
                 data = transform(data)
         return data
 
-    def __repr__(self):
-        args = ['    {},'.format(transform) for transform in self.transforms]
-        return '{}([\n{}\n])'.format(self.__class__.__name__, '\n'.join(args))
+    def __repr__(self) -> str:
+        args = [f'  {transform}' for transform in self.transforms]
+        return '{}([\n{}\n])'.format(self.__class__.__name__, ',\n'.join(args))
