@@ -1,10 +1,16 @@
+from typing import Optional
+
 import torch
 
+from torch_geometric.data import Data
+from torch_geometric.data.datapipes import functional_transform
 from torch_geometric.transforms import BaseTransform
 
 
+@functional_transform('distance')
 class Distance(BaseTransform):
-    r"""Saves the Euclidean distance of linked nodes in its edge attributes.
+    r"""Saves the Euclidean distance of linked nodes in its edge attributes
+    (functional name: :obj:`distance`).
 
     Args:
         norm (bool, optional): If set to :obj:`False`, the output will not be
@@ -15,12 +21,13 @@ class Distance(BaseTransform):
         cat (bool, optional): If set to :obj:`False`, all existing edge
             attributes will be replaced. (default: :obj:`True`)
     """
-    def __init__(self, norm=True, max_value=None, cat=True):
+    def __init__(self, norm: bool = True, max_value: Optional[float] = None,
+                 cat: bool = True):
         self.norm = norm
         self.max = max_value
         self.cat = cat
 
-    def __call__(self, data):
+    def __call__(self, data: Data) -> Data:
         (row, col), pos, pseudo = data.edge_index, data.pos, data.edge_attr
 
         dist = torch.norm(pos[col] - pos[row], p=2, dim=-1).view(-1, 1)
@@ -36,6 +43,6 @@ class Distance(BaseTransform):
 
         return data
 
-    def __repr__(self):
-        return '{}(norm={}, max_value={})'.format(self.__class__.__name__,
-                                                  self.norm, self.max)
+    def __repr__(self) -> str:
+        return (f'{self.__class__.__name__}(norm={self.norm}, '
+                f'max_value={self.max})')
