@@ -24,14 +24,15 @@ class GCNNorm(BaseTransform):
         assert 'edge_index' in data or 'adj_t' in data
 
         if 'edge_index' in data:
-            edge_weight = data.edge_attr
-            if 'edge_weight' in data:
-                edge_weight = data.edge_weight
             data.edge_index, data.edge_weight = gcn_norm(
-                data.edge_index, edge_weight, data.num_nodes,
+                data.edge_index, data.edge_weight, data.num_nodes,
                 add_self_loops=self.add_self_loops)
         else:
             data.adj_t = gcn_norm(data.adj_t,
                                   add_self_loops=self.add_self_loops)
 
         return data
+
+    def __repr__(self) -> str:
+        return (f'{self.__class__.__name__}('
+                f'add_self_loops={self.add_self_loops})')
