@@ -1,10 +1,10 @@
 import torch
 from torch import Tensor
-from torch_scatter import scatter_mean
 
 from torch_geometric.data import Data
 from torch_geometric.data.datapipes import functional_transform
 from torch_geometric.transforms import BaseTransform
+from torch_geometric.utils import scatter
 
 
 @functional_transform('to_slic')
@@ -12,12 +12,12 @@ class ToSLIC(BaseTransform):
     r"""Converts an image to a superpixel representation using the
     :meth:`skimage.segmentation.slic` algorithm, resulting in a
     :obj:`torch_geometric.data.Data` object holding the centroids of
-    superpixels in :obj:`pos` and their mean color in :obj:`x`
+    superpixels in :obj:`data.pos` and their mean color in :obj:`data.x`
     (functional name: :obj:`to_slic`).
 
     This transform can be used with any :obj:`torchvision` dataset.
 
-    Example::
+    .. code-block:: python
 
         from torchvision.datasets import MNIST
         import torchvision.transforms as T
@@ -50,7 +50,7 @@ class ToSLIC(BaseTransform):
         seg = slic(img.to(torch.double).numpy(), start_label=0, **self.kwargs)
         seg = torch.from_numpy(seg)
 
-        x = scatter_mean(img.view(h * w, c), seg.view(h * w), dim=0)
+        x = scatter(img.view(h * w, c), seg.view(h * w), dim=0, reduce='mean')
 
         pos_y = torch.arange(h, dtype=torch.float)
         pos_y = pos_y.view(-1, 1).repeat(1, w).view(h * w)
@@ -58,7 +58,7 @@ class ToSLIC(BaseTransform):
         pos_x = pos_x.view(1, -1).repeat(h, 1).view(h * w)
 
         pos = torch.stack([pos_x, pos_y], dim=-1)
-        pos = scatter_mean(pos, seg.view(h * w), dim=0)
+        pos = scatter(pos, seg.view(h * w), dim=0, reduce='mean')
 
         data = Data(x=x, pos=pos)
 
