@@ -3,10 +3,9 @@ from typing import List, Optional, Tuple, Union
 import torch
 from torch import Tensor
 
-from torch_geometric.typing import PairTensor
-
-from .mask import index_to_mask
-from .num_nodes import maybe_num_nodes
+from torch_geometric.typing import OptTensor, PairTensor
+from torch_geometric.utils.mask import index_to_mask
+from torch_geometric.utils.num_nodes import maybe_num_nodes
 
 
 def get_num_hops(model: torch.nn.Module) -> int:
@@ -40,11 +39,11 @@ def get_num_hops(model: torch.nn.Module) -> int:
 def subgraph(
     subset: Union[Tensor, List[int]],
     edge_index: Tensor,
-    edge_attr: Optional[Tensor] = None,
+    edge_attr: OptTensor = None,
     relabel_nodes: bool = False,
     num_nodes: Optional[int] = None,
     return_edge_mask: bool = False,
-) -> Tuple[Tensor, Tensor]:
+) -> Union[Tuple[Tensor, OptTensor], Tuple[Tensor, OptTensor, OptTensor]]:
     r"""Returns the induced subgraph of :obj:`(edge_index, edge_attr)`
     containing the nodes in :obj:`subset`.
 
@@ -114,11 +113,11 @@ def subgraph(
 def bipartite_subgraph(
     subset: Union[PairTensor, Tuple[List[int], List[int]]],
     edge_index: Tensor,
-    edge_attr: Optional[Tensor] = None,
+    edge_attr: OptTensor = None,
     relabel_nodes: bool = False,
-    size: Tuple[int, int] = None,
+    size: Optional[Tuple[int, int]] = None,
     return_edge_mask: bool = False,
-) -> Tuple[Tensor, Tensor]:
+) -> Union[Tuple[Tensor, OptTensor], Tuple[Tensor, OptTensor, OptTensor]]:
     r"""Returns the induced subgraph of the bipartite graph
     :obj:`(edge_index, edge_attr)` containing the nodes in :obj:`subset`.
 
@@ -161,35 +160,35 @@ def bipartite_subgraph(
 
     device = edge_index.device
 
-    if isinstance(subset[0], (list, tuple)):
-        subset = (torch.tensor(subset[0], dtype=torch.long, device=device),
-                  torch.tensor(subset[1], dtype=torch.long, device=device))
+    src_subset, dst_subset = subset
+    if not isinstance(src_subset, Tensor):
+        src_subset = torch.tensor(src_subset, dtype=torch.long, device=device)
+    if not isinstance(dst_subset, Tensor):
+        dst_subset = torch.tensor(dst_subset, dtype=torch.long, device=device)
 
-    if subset[0].dtype == torch.bool or subset[0].dtype == torch.uint8:
-        size = subset[0].size(0), subset[1].size(0)
-    else:
-        if size is None:
-            size = (maybe_num_nodes(edge_index[0]),
-                    maybe_num_nodes(edge_index[1]))
-        subset = (index_to_mask(subset[0], size=size[0]),
-                  index_to_mask(subset[1], size=size[1]))
+    if src_subset.dtype != torch.bool:
+        src_size = int(edge_index[0].max()) + 1 if size is None else size[0]
+        src_subset = index_to_mask(src_subset, size=src_size)
+    if dst_subset.dtype != torch.bool:
+        dst_size = int(edge_index[1].max()) + 1 if size is None else size[1]
+        dst_subset = index_to_mask(dst_subset, size=dst_size)
 
-    node_mask = subset
-    edge_mask = node_mask[0][edge_index[0]] & node_mask[1][edge_index[1]]
+    # node_mask = subset
+    edge_mask = src_subset[edge_index[0]] & dst_subset[edge_index[1]]
     edge_index = edge_index[:, edge_mask]
     edge_attr = edge_attr[edge_mask] if edge_attr is not None else None
 
     if relabel_nodes:
-        node_idx_i = torch.zeros(node_mask[0].size(0), dtype=torch.long,
-                                 device=device)
-        node_idx_j = torch.zeros(node_mask[1].size(0), dtype=torch.long,
-                                 device=device)
-        node_idx_i[node_mask[0]] = torch.arange(node_mask[0].sum().item(),
-                                                device=device)
-        node_idx_j[node_mask[1]] = torch.arange(node_mask[1].sum().item(),
-                                                device=device)
-        edge_index = torch.stack(
-            [node_idx_i[edge_index[0]], node_idx_j[edge_index[1]]])
+        node_idx_i = edge_index.new_zeros(src_subset.size(0))
+        node_idx_j = edge_index.new_zeros(dst_subset.size(0))
+        node_idx_i[src_subset] = torch.arange(int(src_subset.sum()),
+                                              device=node_idx_i.device)
+        node_idx_j[dst_subset] = torch.arange(int(dst_subset.sum()),
+                                              device=node_idx_j.device)
+        edge_index = torch.stack([
+            node_idx_i[edge_index[0]],
+            node_idx_j[edge_index[1]],
+        ], dim=0)
 
     if return_edge_mask:
         return edge_index, edge_attr, edge_mask
@@ -204,6 +203,7 @@ def k_hop_subgraph(
     relabel_nodes: bool = False,
     num_nodes: Optional[int] = None,
     flow: str = 'source_to_target',
+    directed: bool = False,
 ) -> Tuple[Tensor, Tensor, Tensor, Tensor]:
     r"""Computes the induced subgraph of :obj:`edge_index` around all nodes in
     :attr:`node_idx` reachable within :math:`k` hops.
@@ -229,9 +229,11 @@ def k_hop_subgraph(
             starting from zero. (default: :obj:`False`)
         num_nodes (int, optional): The number of nodes, *i.e.*
             :obj:`max_val + 1` of :attr:`edge_index`. (default: :obj:`None`)
-        flow (string, optional): The flow direction of :math:`k`-hop
-            aggregation (:obj:`"source_to_target"` or
-            :obj:`"target_to_source"`). (default: :obj:`"source_to_target"`)
+        flow (str, optional): The flow direction of :math:`k`-hop aggregation
+            (:obj:`"source_to_target"` or :obj:`"target_to_source"`).
+            (default: :obj:`"source_to_target"`)
+        directed (bool, optional): If set to :obj:`False`, will include all
+            edges between all sampled nodes. (default: :obj:`True`)
 
     :rtype: (:class:`LongTensor`, :class:`LongTensor`, :class:`LongTensor`,
              :class:`BoolTensor`)
@@ -304,7 +306,9 @@ def k_hop_subgraph(
 
     node_mask.fill_(False)
     node_mask[subset] = True
-    edge_mask = node_mask[row] & node_mask[col]
+
+    if not directed:
+        edge_mask = node_mask[row] & node_mask[col]
 
     edge_index = edge_index[:, edge_mask]
 
